@@ -20,20 +20,26 @@ Implementation of BoundingBox class and related methods
 """
 
 from dataclasses import dataclass
-from typing import List, Optional, Union
+from math import ceil, floor
+from typing import List, Optional
 
 import numpy as np
 import numpy.typing as npt
-import pycocotools.mask as coco_mask
 from numpy import float32
 
 from ..utils.detection_types import ImageType
+from ..utils.file_utils import cocotools_available
+
+if cocotools_available():
+    import pycocotools.mask as coco_mask
 
 
-# Much faster than utils/np_box_ops
-def np_iou(box_a: npt.NDArray[float32], box_b: npt.NDArray[float32]) -> npt.NDArray[float32]:
+# taken from https://github.com/tensorpack/tensorpack/blob/master/examples/FasterRCNN/common.py
+
+
+def coco_iou(box_a: npt.NDArray[float32], box_b: npt.NDArray[float32]) -> npt.NDArray[float32]:
     """
-    Calculate iou for two arrays of bounding boxes
+    Calculate iou for two arrays of bounding boxes in xyxy format
 
     :param box_a: Array of shape Nx4
     :param box_b: Array of shape Mx4
@@ -47,11 +53,92 @@ def np_iou(box_a: npt.NDArray[float32], box_b: npt.NDArray[float32]) -> npt.NDAr
         box[:, 3] -= box[:, 1]
         return box
 
-    ret = coco_mask.iou(to_xywh(box_a), to_xywh(box_b), np.zeros((len(box_b),), dtype=np.bool))  # type: ignore
+    ret = coco_mask.iou(to_xywh(box_a), to_xywh(box_b), np.zeros((len(box_b),), dtype=bool))
     # can accelerate even more, if using float32
     return ret.astype("float32")
 
 
+# taken from https://github.com/tensorpack/tensorpack/blob/master/examples/FasterRCNN/utils/np_box_ops.py
+
+
+def area(boxes: npt.NDArray[float32]) -> npt.NDArray[float32]:
+    """
+    Computes area of boxes.
+
+    :param boxes: numpy array with shape [N, 4] holding N boxes in xyxy format
+
+    :return: a numpy array with shape [N*1] representing box areas
+    """
+    return np.array((boxes[:, 2] - boxes[:, 0]) * (boxes[:, 3] - boxes[:, 1]), dtype=float32)
+
+
+# taken from https://github.com/tensorpack/tensorpack/blob/master/examples/FasterRCNN/utils/np_box_ops.py
+
+
+def intersection(boxes1: npt.NDArray[float32], boxes2: npt.NDArray[float32]) -> npt.NDArray[float32]:
+    """
+    Compute pairwise intersection areas between boxes.
+
+    :param boxes1: a numpy array with shape [N, 4] holding N boxes in xyxy format
+    :param  boxes2: a numpy array with shape [M, 4] holding M boxes in xyxy format
+
+    :return: a numpy array with shape [N*M] representing pairwise intersection area
+    """
+    [y_min1, x_min1, y_max1, x_max1] = np.split(boxes1, 4, axis=1)  # pylint: disable=W0632
+    [y_min2, x_min2, y_max2, x_max2] = np.split(boxes2, 4, axis=1)  # pylint: disable=W0632
+
+    all_pairs_min_ymax = np.minimum(y_max1, np.transpose(y_max2))
+    all_pairs_max_ymin = np.maximum(y_min1, np.transpose(y_min2))
+    intersect_heights = np.maximum(
+        np.zeros(all_pairs_max_ymin.shape, dtype="f4"), all_pairs_min_ymax - all_pairs_max_ymin
+    )
+    all_pairs_min_xmax = np.minimum(x_max1, np.transpose(x_max2))
+    all_pairs_max_xmin = np.maximum(x_min1, np.transpose(x_min2))
+    intersect_widths = np.maximum(
+        np.zeros(all_pairs_max_xmin.shape, dtype="f4"), all_pairs_min_xmax - all_pairs_max_xmin
+    )
+    return intersect_heights * intersect_widths
+
+
+# taken from https://github.com/tensorpack/tensorpack/blob/master/examples/FasterRCNN/utils/np_box_ops.py
+
+
+def np_iou(boxes1: npt.NDArray[float32], boxes2: npt.NDArray[float32]) -> npt.NDArray[float32]:
+    """
+    Computes pairwise intersection-over-union between box collections.
+
+    :param  boxes1: a numpy array with shape [N, 4] holding N boxes in xyxy format.
+    :param  boxes2: a numpy array with shape [M, 4] holding M boxes in xyxy format.
+
+    :return:  a numpy array with shape [N, M] representing pairwise iou scores.
+    """
+    intersect = intersection(boxes1, boxes2)
+    area1 = area(boxes1)
+    area2 = area(boxes2)
+    union = np.expand_dims(area1, axis=1) + np.expand_dims(area2, axis=0) - intersect
+
+    return intersect / union
+
+
+def iou(boxes1: npt.NDArray[float32], boxes2: npt.NDArray[float32]) -> npt.NDArray[float32]:
+    """
+    Computes pairwise intersection-over-union between box collections. The method will be chosen based on what
+    is installed:
+
+    - If pycocotools is installed it will choose pycocotools.mask.iou which is a cython implementation and much faster
+    - Otherwise it will use the numpy implementation as fallback
+
+    :param boxes1:  a numpy array with shape [N, 4] holding N boxes in xyxy format.
+    :param boxes2:  a numpy array with shape [N, 4] holding N boxes in xyxy format.
+
+    :return: a numpy array with shape [N, M] representing pairwise iou scores.
+    """
+
+    if cocotools_available():
+        return coco_iou(boxes1, boxes2)
+    return np_iou(boxes1, boxes2)
+
+
 @dataclass
 class BoundingBox:
     """
@@ -109,7 +196,7 @@ class BoundingBox:
 
         if not self.absolute_coords:
             assert (
-                self.ulx <= 1 and self.uly <= 1 and self.lrx <= 1 and self.lry <= 1
+                self.ulx <= 1.0 and self.uly <= 1.0 and self.lrx <= 1.0 and self.lry <= 1.0
             ), "coordinates must be between 0 and 1"
 
     @property
@@ -166,7 +253,7 @@ class BoundingBox:
             * np_poly_scale
         )
 
-    def to_list(self, mode: str, scale_x: float = 1, scale_y: float = 1.0) -> List[float]:
+    def to_list(self, mode: str, scale_x: float = 1.0, scale_y: float = 1.0) -> List[float]:
         """
         Returns the coordinates as list
 
@@ -181,27 +268,27 @@ class BoundingBox:
         assert mode in ("xyxy", "xywh", "poly"), "not a valid mode"
         if mode == "xyxy":
             return [
-                float(self.ulx) * scale_x,
-                float(self.uly) * scale_y,
-                float(self.lrx) * scale_x,
-                float(self.lry) * scale_y,
+                self.ulx * scale_x,
+                self.uly * scale_y,
+                self.lrx * scale_x,
+                self.lry * scale_y,
             ]
         if mode == "xywh":
             return [
-                float(self.ulx) * scale_x,
-                float(self.uly) * scale_y,
-                float(self.width) * scale_x,
-                float(self.height) * scale_y,
+                self.ulx * scale_x,
+                self.uly * scale_y,
+                self.width * scale_x,
+                self.height * scale_y,
             ]
         return [
-            float(self.ulx) * scale_x,
-            float(self.uly) * scale_y,
-            float(self.lrx) * scale_x,
-            float(self.uly) * scale_y,
-            float(self.lrx) * scale_x,
-            float(self.lry) * scale_y,
-            float(self.ulx) * scale_x,
-            float(self.lry) * scale_y,
+            self.ulx * scale_x,
+            self.uly * scale_y,
+            self.lrx * scale_x,
+            self.uly * scale_y,
+            self.lrx * scale_x,
+            self.lry * scale_y,
+            self.ulx * scale_x,
+            self.lry * scale_y,
         ]
 
     def transform(
@@ -209,9 +296,7 @@ class BoundingBox:
         image_width: float,
         image_height: float,
         absolute_coords: bool = False,
-        output: str = "list",
-        mode: str = "xyxy",
-    ) -> Union[npt.NDArray[np.float32], List[float], "BoundingBox"]:
+    ) -> "BoundingBox":
         """
         Transforms bounding box coordinates into absolute or relative coords. Internally, a new bounding box will be
         created. Changing coordinates requires width and height of the whole image.
@@ -219,13 +304,9 @@ class BoundingBox:
         :param image_width: The horizontal image size
         :param image_height: The vertical image size
         :param absolute_coords: Whether to recalculate into absolute coordinates.
-        :param output: If true will return the bounding box as list, otherwise as numpy array
-        :param mode: "xyxy", "xywh" or "poly" mode as described in :meth:`BoundingBox.as_list`
-                     or :meth:`BoundingBox.as_np_array`.
 
         :return: Either a list or np.array.
         """
-        assert output in ["list", "np", "box"]
 
         if absolute_coords != self.absolute_coords:  # only transforming in this case
             if self.absolute_coords:
@@ -244,16 +325,7 @@ class BoundingBox:
                     lrx=self.lrx * image_width,
                     lry=self.lry * image_height,
                 )
-
-            if output == "list":
-                return transformed_box.to_list(mode)
-            if output == "np":
-                return transformed_box.to_np_array(mode)
             return transformed_box
-        if output == "list":
-            return self.to_list(mode)
-        if output == "np":
-            return self.to_np_array(mode)
         return self
 
     def __str__(self) -> str:
@@ -285,13 +357,13 @@ def intersection_box(
 
     :return: bounding box. Will have same absolute_coords as box_2, if absolute_coords of box_1 and box_2 are note same
     """
-    if width is None and height is None:
-        assert box_1.absolute_coords == box_2.absolute_coords, (
-            "when absolute coords of boxes are not equal must " "pass width and height"
-        )
+
     if box_1.absolute_coords != box_2.absolute_coords:
         # will transform box_1
-        box_1 = box_1.transform(width, height, box_2.absolute_coords, output="box")  # type: ignore
+        assert (
+            width is not None and height is not None
+        ), "when absolute coords of boxes are not equal must pass width and height"
+        box_1 = box_1.transform(width, height, box_2.absolute_coords)
     ulx = max(box_1.ulx, box_2.ulx)
     uly = max(box_1.uly, box_2.uly)
     lrx = min(box_1.lrx, box_2.lrx)
@@ -317,24 +389,19 @@ def crop_box_from_image(
 
     :return: A numpy array cropped according to the bounding box.
     """
-    if width is None and height is None:
-        assert crop_box.absolute_coords, (
-            "when crop_box has absolute coords set to False, then width and height are " "positional args"
-        )
-    absolute_coord_box = (
-        crop_box
-        if crop_box.absolute_coords
-        else crop_box.transform(width, height, absolute_coords=True, output="box")  # type: ignore
-    )
+    if not crop_box.absolute_coords:
+        assert (
+            width is not None and height is not None
+        ), "when crop_box has absolute coords set to False must pass width and height"
+        absolute_coord_box = crop_box.transform(width, height, absolute_coords=True)
+    else:
+        absolute_coord_box = crop_box
+
     assert isinstance(absolute_coord_box, BoundingBox)
     np_max_y, np_max_x = np_image.shape[0:2]
-    return np_image[  # type: ignore
-        np.int32(np.floor(absolute_coord_box.uly)) : min(  # type: ignore
-            np.int32(np.ceil(absolute_coord_box.lry)), np_max_y
-        ),
-        np.int32(np.floor(absolute_coord_box.ulx)) : min(  # type: ignore
-            np.int32(np.ceil(absolute_coord_box.lrx)), np_max_x
-        ),
+    return np_image[
+        int(floor(absolute_coord_box.uly)) : min(int(ceil(absolute_coord_box.lry)), np_max_y),
+        int(floor(absolute_coord_box.ulx)) : min(int(ceil(absolute_coord_box.lrx)), np_max_x),
     ]
 
 
