@@ -18,14 +18,18 @@
 """
 Dataclass Image
 """
-from typing import Iterable
+from copy import deepcopy
+from dataclasses import dataclass, field
+from typing import Any, Dict, Iterable, List, Optional, Sequence, Union
 
 import numpy as np
+from numpy import uint8
 
 from ..utils.detection_types import ImageType
-from .annotation import *  # pylint: disable=W0401, W0614
+from ..utils.identifier import get_uuid, is_uuid_like
+from .annotation import Annotation, BoundingBox, ImageAnnotation, SummaryAnnotation
 from .box import crop_box_from_image, global_to_local_coords, intersection_box
-from .convert import convert_b64_to_np_array, convert_np_array_to_b64, convert_pdf_bytes_to_np_array_v2
+from .convert import as_dict, convert_b64_to_np_array, convert_np_array_to_b64, convert_pdf_bytes_to_np_array_v2
 
 
 @dataclass
@@ -71,17 +75,13 @@ class Image:
     """
 
     file_name: str
-    location: str = field(default_factory=str)
-    external_id: Optional[Union[str, int]] = field(default=None, init=True, repr=False)
-    image_id: str = field(init=False, repr=True)
-    _image_id: Optional[str] = field(default=None, init=False, repr=False)
-    image: Optional[ImageType] = field(init=False, repr=False)
+    location: str = field(default="")
+    external_id: Optional[Union[str, int]] = field(default=None, repr=False)
+    _image_id: Optional[str] = field(default=None, init=False, repr=True)
     _image: Optional[ImageType] = field(default=None, init=False, repr=False)
     _bbox: Optional[BoundingBox] = field(default=None, init=False, repr=False)
-    _embeddings: Dict[str, BoundingBox] = field(default_factory=dict, init=False, repr=False)
     embeddings: Dict[str, BoundingBox] = field(default_factory=dict, init=False, repr=True)
     annotations: List[ImageAnnotation] = field(default_factory=list, init=False, repr=True)
-    _annotations: List[ImageAnnotation] = field(default_factory=list, init=False, repr=False)
     _annotation_ids: List[str] = field(default_factory=list, init=False, repr=False)
     summary: Optional[SummaryAnnotation] = field(default=None, init=False, repr=False)
 
@@ -95,8 +95,8 @@ class Image:
         else:
             self.image_id = get_uuid(self.location, self.file_name)
 
-    @property  # type: ignore
-    def image_id(self) -> str:  # pylint: disable=E0102
+    @property
+    def image_id(self) -> str:
         """
         image_id
         """
@@ -118,8 +118,8 @@ class Image:
         else:
             raise ValueError("image_id must be uuid3 string")
 
-    @property  # type: ignore
-    def image(self) -> Optional[ImageType]:  # pylint: disable=E0102
+    @property
+    def image(self) -> Optional[ImageType]:
         """
         image
         """
@@ -147,43 +147,17 @@ class Image:
             self._self_embedding()
         else:
             assert isinstance(image, np.ndarray), f"cannot load image is of type: {type(image)}"
-            self._image = image
+            self._image = image.astype(uint8)
             self.set_width_height(self._image.shape[1], self._image.shape[0])
             self._self_embedding()
 
-    @property  # type: ignore
-    def embeddings(self) -> Dict[str, BoundingBox]:  # pylint: disable=E0102
-        """
-        embeddings. Rather use :meth:`get_embedding`
-        """
-        return self._embeddings
-
-    @embeddings.setter
-    def embeddings(self, inputs: Dict[str, BoundingBox]) -> None:
-        """
-        embedding setter. Only defined for technical reasons. Cannot change the underlying attribute from here.
-        """
-
-    @property  # type: ignore
-    def annotations(self) -> List[ImageAnnotation]:  # pylint: disable=E0102
-        """
-        annotations. Rather use :meth:`get_annotations` directly or with some specified filter conditions.
-        """
-        return self._annotations
-
-    @annotations.setter
-    def annotations(self, inputs: List[ImageAnnotation]) -> None:
-        """
-        annotations setter. Only defined for technical reasons. Cannot change the underlying attribute from here.
-        """
-
     @property
     def pdf_bytes(self) -> Optional[bytes]:
         """
         pdf_bytes. This attribute will be set dynamically and is not part of the core Image data model
         """
         if hasattr(self, "_pdf_bytes"):
-            return self._pdf_bytes  # type: ignore
+            return getattr(self, "_pdf_bytes")
         return None
 
     @pdf_bytes.setter
@@ -201,20 +175,53 @@ class Image:
         """
         self._image = None
 
-    def get_image(self, type_id: str) -> Optional[Union[ImageType, str]]:
+    def get_image(self) -> "_Img":  # type: ignore
         """
         Get the image either in base64 string representation or as np.array.
 
-        :param type_id: "b64" or "np"
+        .. code-block:: python
+
+            image.get_image().to_np_array()
+
+        or
+
+        .. code-block:: python
+
+            image.get_image().to_b64()
+
         :return: desired image encoding representation
         """
-        assert type_id in ["b64", "np"], type_id
-        if type_id == "b64" and self.image is not None:
-            return convert_np_array_to_b64(self.image)
-        return self.image
+
+        class _Img:
+            """
+            Helper class. Do not use it in your code.
+            """
+
+            def __init__(self, img: Optional[ImageType]):
+                self.img = img
+
+            def to_np_array(self) -> Optional[ImageType]:
+                """
+                Returns image as numpy array
+
+                :return: array
+                """
+                return self.img
+
+            def to_b64(self) -> Optional[str]:
+                """
+                Returns image as b64 encoded string
+
+                :return: b64 encoded string
+                """
+                if self.img is not None:
+                    return convert_np_array_to_b64(self.img)
+                return self.img
+
+        return _Img(self.image)
 
     @property
-    def width(self) -> float:  # pylint: disable=R1710
+    def width(self) -> float:
         """
         width
         """
@@ -223,7 +230,7 @@ class Image:
         return self._bbox.width
 
     @property
-    def height(self) -> float:  # pylint: disable=R1710
+    def height(self) -> float:
         """
         height
         """
@@ -252,7 +259,7 @@ class Image:
         :param bounding_box: bounding box of this image in terms of the embedding image.
         """
         assert isinstance(bounding_box, BoundingBox), "bounding box must be of type BoundingBox"
-        self._embeddings[image_id] = bounding_box
+        self.embeddings[image_id] = bounding_box
 
     def get_embedding(self, image_id: str) -> BoundingBox:
         """
@@ -262,7 +269,7 @@ class Image:
         :return: The bounding box of this instance in terms of the embedding image
         """
 
-        return self._embeddings[image_id]
+        return self.embeddings[image_id]
 
     def _self_embedding(self) -> None:
         if self._bbox is not None:
@@ -282,18 +289,18 @@ class Image:
             f"{annotation.annotation_id} but is of type {str(type(annotation))}"
         )
         if annotation._annotation_id is None:  # pylint: disable=W0212
-            annotation.annotation_id = self._define_annotation_id(annotation)
+            annotation.annotation_id = self.define_annotation_id(annotation)
         assert annotation.annotation_id not in self._annotation_ids, (
             f"Cannot dump annotation with already taken " f"id {annotation.annotation_id}"
         )
         self._annotation_ids.append(annotation.annotation_id)
-        self._annotations.append(annotation)
+        self.annotations.append(annotation)
 
     def get_annotation(
         self,
-        category_names: Optional[Union[str, List[str]]] = None,
-        annotation_ids: Optional[Union[str, List[str]]] = None,
-        annotation_types: Optional[Union[str, List[str]]] = None,
+        category_names: Optional[Union[str, Sequence[str]]] = None,
+        annotation_ids: Optional[Union[str, Sequence[str]]] = None,
+        annotation_types: Optional[Union[str, Sequence[str]]] = None,
     ) -> List[ImageAnnotation]:
         """
         Selection of annotations from the annotation container. Filter conditions can be defined by specifying
@@ -312,17 +319,17 @@ class Image:
         ann_ids = [annotation_ids] if isinstance(annotation_ids, str) else annotation_ids
         ann_types = [annotation_types] if isinstance(annotation_types, str) else annotation_types
 
-        anns = filter(lambda x: x.active, self._annotations)
+        anns = filter(lambda x: x.active, self.annotations)
 
         if ann_types is not None:
             for type_name in ann_types:
                 anns = filter(lambda x: isinstance(x, eval(type_name)), anns)  # pylint: disable=W0123, W0640
 
         if cat_names is not None:
-            anns = filter(lambda x: x.category_name in cat_names, anns)  # type: ignore
+            anns = filter(lambda x: x.category_name in cat_names, anns)  # type:ignore
 
         if ann_ids is not None:
-            anns = filter(lambda x: x.annotation_id in annotation_ids, anns)  # type: ignore
+            anns = filter(lambda x: x.annotation_id in ann_ids, anns)  # type:ignore
 
         return list(anns)
 
@@ -361,9 +368,17 @@ class Image:
         A list of attributes to suspend from as_dict creation.
         """
 
-        return ["external_id", "_image_id", "_image", "_bbox", "_embeddings", "_annotations"]
+        return ["external_id", "_image", "_bbox", "_embeddings", "_annotations"]
+
+    def define_annotation_id(self, annotation: Annotation) -> str:
+        """
+        Generate a uuid for a given annotation. To guarantee uniqueness the generation depends on the datapoint
+        image_id as well as on the annotation.
+
+        :param annotation:  An annotation to generate the uuid for
+        :return: uuid string
+        """
 
-    def _define_annotation_id(self, annotation: Annotation) -> str:
         attributes = annotation.get_defining_attributes()
         attributes_values = [str(getattr(annotation, attribute)) for attribute in attributes]
         assert self.image_id is not None
@@ -371,12 +386,15 @@ class Image:
 
     def remove(self, annotation: ImageAnnotation) -> None:
         """
+        Instead of removing consider deactivating annotations.
+
         Calls :meth:`List.remove`. Make sure, the element is in the list for otherwise a ValueError will be raised.
 
         :param annotation: The annotation to remove
         """
 
-        self._annotations.remove(annotation)
+        self.annotations.remove(annotation)
+        self._annotation_ids.remove(annotation.annotation_id)
 
     def image_ann_to_image(self, annotation_id: str, crop_image: bool = False) -> None:
         """
@@ -431,7 +449,9 @@ class Image:
         assert ann.bounding_box is not None
         box = ann.bounding_box.to_list("xyxy")
         proposals = self.get_annotation(category_names)
-        points = np.array([prop.image.get_embedding(self.image_id).center for prop in proposals])  # type: ignore
+        points = np.array(
+            [prop.image.get_embedding(self.image_id).center for prop in proposals if prop.image is not None]
+        )
         ann_ids = np.array([prop.annotation_id for prop in proposals])
         indices = np.where(
             (box[0] < points[:, 0]) & (box[1] < points[:, 1]) & (box[2] > points[:, 0]) & (box[3] > points[:, 1])
@@ -457,12 +477,12 @@ class Image:
         """
 
         image_copy = deepcopy(self)
-        image_copy._annotations = []  # pylint: disable=W0212
+        image_copy.annotations = []
         image_copy.image = np.ones((1, 1, 3), dtype=np.float32)
         export_dict = image_copy.as_dict()
         export_dict["annotations"] = []
-        export_dict["image"] = self.get_image(type_id="b64")
-        for ann in self._annotations:
+        export_dict["image"] = self.get_image().to_b64()
+        for ann in self.annotations:
             export_dict["annotations"].append(ann.get_export())
 
         return export_dict
