@@ -37,31 +37,34 @@ Module for IIITar13K dataset. Install the dataset following the folder structure
 """
 
 import os
-from typing import Dict, List, Union
+from typing import Mapping, Union
 
-from lxml import etree  # type: ignore
-
-from ...dataflow import DataFlow, MapData, SerializerFiles  # type: ignore
+from ...dataflow import DataFlow, MapData, SerializerFiles
 from ...datasets.info import DatasetInfo
-from ...mapper.maputils import cur
+from ...mapper.maputils import curry
 from ...mapper.misc import xml_to_dict
 from ...mapper.pascalstruct import pascal_voc_dict_to_image
 from ...utils.detection_types import JsonDict
+from ...utils.file_utils import lxml_available
 from ...utils.settings import names
 from ...utils.systools import get_package_path
 from ..base import _BuiltInDataset
 from ..dataflow_builder import DataFlowBaseBuilder
 from ..info import DatasetCategories
+from ..registry import dataset_registry
+
+if lxml_available():
+    from lxml import etree  # type: ignore
 
 _NAME = "iiitar13k"
 
 _DESCRIPTION = (
-    "[excerpt from Ajoy Mondal et. all. IIIT-AR-13K: A New Dataset for Graphical Object Detection in "
-    "Documents] ...This dataset, IIIT-AR-13K, is created by manually annotating the bounding boxes of "
-    "graphical or page objects in publicly available annual reports. This dataset contains a total of 13K "
-    "annotated page images with objects in five different popular categories — table, figure, natural "
-    "image, logo, and signature. This is the largest manually annotated dataset for graphical object "
-    "detection. Annual reports created in multiple languages for several years from various companies "
+    "[excerpt from Ajoy Mondal et. all. IIIT-AR-13K: A New Dataset for Graphical Object Detection in \n"
+    "Documents] ...This dataset, IIIT-AR-13K, is created by manually annotating the bounding boxes of \n"
+    "graphical or page objects in publicly available annual reports. This dataset contains a total of 13K \n"
+    "annotated page images with objects in five different popular categories — table, figure, natural \n"
+    "image, logo, and signature. This is the largest manually annotated dataset for graphical object \n"
+    "detection. Annual reports created in multiple languages for several years from various companies \n"
     "bring high diversity into this dataset."
 )
 
@@ -69,9 +72,9 @@ _LICENSE = "NN"
 
 _URL = "http://cvit.iiit.ac.in/usodi/iiitar13k.php"
 
-_SPLITS = {"train": "training_images", "val": "validation_images", "test": "test_images"}
-_LOCATION = "/iiitar13k"
-_ANNOTATION_FILES: Dict[str, Union[str, List[str]]] = {
+_SPLITS: Mapping[str, str] = {"train": "training_images", "val": "validation_images", "test": "test_images"}
+_LOCATION = "iiitar13k"
+_ANNOTATION_FILES: Mapping[str, str] = {
     "train": "training_xml",
     "val": "validation_xml",
     "test": "test_xml",
@@ -80,6 +83,7 @@ _ANNOTATION_FILES: Dict[str, Union[str, List[str]]] = {
 _INIT_CATEGORIES = [names.C.TAB, names.C.LOGO, names.C.FIG, names.C.SIGN]
 
 
+@dataset_registry.register("iiitar13k")
 class IIITar13K(_BuiltInDataset):
     """
     IIITar13K
@@ -87,7 +91,8 @@ class IIITar13K(_BuiltInDataset):
 
     _name = _NAME
 
-    def _info(self) -> DatasetInfo:
+    @classmethod
+    def _info(cls) -> DatasetInfo:
         return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, url=_URL, splits=_SPLITS)
 
     def _categories(self) -> DatasetCategories:
@@ -124,12 +129,14 @@ class IIITar13KBuilder(DataFlowBaseBuilder):
             max_datapoints = int(max_datapoints)
 
         # Load
-        path_ann_files = os.path.join(self.get_workdir(), self.annotation_files[split])  # type: ignore
+        annotation_split = self.annotation_files[split]
+        assert isinstance(annotation_split, str)
+        path_ann_files = self.get_workdir() / annotation_split
 
         df = SerializerFiles.load(path_ann_files, ".xml", max_datapoints)
         utf8_parser = etree.XMLParser(encoding="utf-8")
 
-        @cur  # type: ignore
+        @curry
         def load_xml(path_ann: str, utf8_parser: etree.XMLParser) -> JsonDict:
             with open(path_ann, "r", encoding="utf-8") as xml_file:
                 root = etree.fromstring(xml_file.read().encode("utf_8"), parser=utf8_parser)
@@ -155,8 +162,8 @@ class IIITar13KBuilder(DataFlowBaseBuilder):
         df = MapData(df, _map_file_name)
         df = MapData(
             df,
-            pascal_voc_dict_to_image(  # type: ignore # pylint: disable = E1120
-                self.categories.get_categories(init=True, name_as_key=True),  # type: ignore
+            pascal_voc_dict_to_image(  # pylint: disable = E1120
+                self.categories.get_categories(init=True, name_as_key=True),
                 load_image,
                 filter_empty_image=True,
                 fake_score=fake_score,
