@@ -29,10 +29,10 @@ Module for Publaynet dataset. Place the dataset as follows
 |    ├── val.json
 """
 
-import os
-from typing import Dict, List, Union
 
-from ...dataflow import DataFlow, MapData, MapDataComponent  # type: ignore
+from typing import Mapping, Union
+
+from ...dataflow import DataFlow, MapData, MapDataComponent
 from ...dataflow.custom_serialize import SerializerCoco
 from ...datasets.info import DatasetInfo
 from ...mapper.cats import filter_cat
@@ -41,33 +41,35 @@ from ...utils.settings import names
 from ..base import _BuiltInDataset
 from ..dataflow_builder import DataFlowBaseBuilder
 from ..info import DatasetCategories
+from ..registry import dataset_registry
 
 _NAME = "publaynet"
 _DESCRIPTION = (
     "PubLayNet is a dataset for document layout analysis. It contains images of research papers and "
-    "articles"
+    "articles \n"
     " and annotations for various elements in a page such as “text”, “list”, “figure” etc in these "
-    "research"
-    " paper images. The dataset was obtained by automatically matching the XML representations and the"
-    " content of over 1 million PDF articles that are publicly available on PubMed Central."
+    "research \n"
+    " paper images. The dataset was obtained by automatically matching the XML representations and the \n"
+    " content of over 1 million PDF articles that are publicly available on PubMed Central. \n"
 )
 _LICENSE = (
-    "The annotations in this dataset belong to IBM and are licensed under a Community Data License Agreement"
-    " – Permissive – Version 1.0 License. IBM does not own the copyright of the images. Use of the images"
+    "The annotations in this dataset belong to IBM and are licensed under a Community Data License Agreement \n"
+    " – Permissive – Version 1.0 License. IBM does not own the copyright of the images. Use of the images \n"
     " must abide by the PMC Open Access Subset Terms of Use."
 )
 _URL = (
     "https://dax-cdn.cdn.appdomain.cloud/dax-publaynet/1.0.0/"
     "publaynet.tar.gz?_ga=2.23017467.1796315263.1628754613-1173244232.1625045842"
 )
-_SPLITS = {"train": "/train", "val": "/val"}
+_SPLITS: Mapping[str, str] = {"train": "train", "val": "val"}
 
-_LOCATION = "/publaynet"
+_LOCATION = "publaynet"
 
-_ANNOTATION_FILES: Dict[str, Union[str, List[str]]] = {"train": "train.json", "val": "val.json"}
+_ANNOTATION_FILES: Mapping[str, str] = {"train": "train.json", "val": "val.json"}
 _INIT_CATEGORIES = [names.C.TEXT, names.C.TITLE, names.C.LIST, names.C.TAB, names.C.FIG]
 
 
+@dataset_registry.register("publaynet")
 class Publaynet(_BuiltInDataset):
     """
     Publaynet
@@ -75,7 +77,8 @@ class Publaynet(_BuiltInDataset):
 
     _name = _NAME
 
-    def _info(self) -> DatasetInfo:
+    @classmethod
+    def _info(cls) -> DatasetInfo:
         return DatasetInfo(name=_NAME, description=_DESCRIPTION, license=_LICENSE, url=_URL, splits=_SPLITS)
 
     def _categories(self) -> DatasetCategories:
@@ -90,7 +93,7 @@ class PublaynetBuilder(DataFlowBaseBuilder):
     Publaynet dataflow builder
     """
 
-    def build(self, **kwargs: Union[str, int]) -> DataFlow:  # pylint: disable=W0221 (#3812)   type: ignore
+    def build(self, **kwargs: Union[str, int]) -> DataFlow:
         """
         Returns a dataflow from which you can stream datapoints of images. The following arguments affect the returns
         of the dataflow:
@@ -110,13 +113,15 @@ class PublaynetBuilder(DataFlowBaseBuilder):
         fake_score = kwargs.get("fake_score", False)
 
         # Load
-        path = os.path.join(self.get_workdir(), self.annotation_files[split])  # type: ignore
+        dataset_split = self.annotation_files[split]
+        assert isinstance(dataset_split, str)
+        path = self.get_workdir() / dataset_split
         df = SerializerCoco.load(path, max_datapoints=max_datapoints)
 
         # Map
-        df = MapDataComponent(df, lambda dp: self.get_workdir() + self.get_split(split) + "/" + dp, "file_name")
-        coco_mapper = coco_to_image(  # type: ignore # pylint: disable=E1120  # 259
-            self.categories.get_categories(init=True),  # type: ignore
+        df = MapDataComponent(df, lambda dp: self.get_workdir() / self.get_split(split) / dp, "file_name")
+        coco_mapper = coco_to_image(  # pylint: disable=E1120  # 259
+            self.categories.get_categories(init=True),
             load_image,
             filter_empty_image=True,
             fake_score=fake_score,
@@ -127,7 +132,7 @@ class PublaynetBuilder(DataFlowBaseBuilder):
         if self.categories.is_filtered():
             df = MapData(
                 df,
-                filter_cat(  # type: ignore  # pylint: disable=E1120
+                filter_cat(  # pylint: disable=E1120
                     self.categories.get_categories(as_dict=False, filtered=True),
                     self.categories.get_categories(as_dict=False, filtered=False),
                 ),
