@@ -86,7 +86,7 @@ def d2_predict_image(
     resized_img = resizer.get_transform(np_img).apply_image(np_img)
     image = torch.as_tensor(resized_img.astype("float32").transpose(2, 0, 1))
 
-    with torch.no_grad():  # type: ignore
+    with torch.no_grad():
         inputs = {"image": image, "height": height, "width": width}
         predictions = predictor([inputs])[0]
         predictions = _d2_post_processing(predictions, nms_thresh_class_agnostic)
@@ -112,6 +112,16 @@ class D2FrcnnDetector(ObjectDetector):
     There are no adjustment to the original implementation of Detectron2. Only one post-processing step is followed by
     the standard D2 output that takes into account of the situation that detected objects are disjoint. For more infos
     on this topic, see https://github.com/facebookresearch/detectron2/issues/978 .
+
+    .. code-block:: python
+
+        config_path = ModelCatalog.get_full_path_configs("dd/d2/item/CASCADE_RCNN_R_50_FPN_GN.yaml")
+        weights_path = ModelDownloadManager.maybe_download_weights_and_configs("item/d2_model-800000-layout.pkl")
+        categories = ModelCatalog.get_profile("item/d2_model-800000-layout.pkl").categories
+
+        d2_predictor = D2FrcnnDetector(config_path,weights_path,categories,device="cpu")
+
+        detection_results = d2_predictor.predict(bgr_image_np_array)
     """
 
     def __init__(
