@@ -20,7 +20,7 @@ HF Layoutlm model for diverse downstream tasks.
 """
 
 from copy import copy
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, Sequence, Union
 
 from ..utils.detection_types import Requirement
 from ..utils.file_utils import (
@@ -34,11 +34,11 @@ from .base import LMTokenClassifier, PredictorBase, TokenClassResult
 from .pt.ptutils import set_torch_auto_device
 
 if pytorch_available():
-    import torch  # pylint: disable=W0611
+    import torch
     from torch import Tensor  # pylint: disable=W0611
 
 if transformers_available():
-    from transformers import LayoutLMForTokenClassification
+    from transformers import LayoutLMForTokenClassification, PretrainedConfig
 
 
 def predict_token_classes(
@@ -75,13 +75,43 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
     Check https://huggingface.co/docs/transformers/model_doc/layoutlm for documentation of the model itself.
     Note that this model is equipped with a head that is only useful when classifying tokens. For sequence
     classification and other things please use another model of the family.
+
+    **Example**
+
+        .. code-block:: python
+
+            # setting up compulsory ocr service
+            tesseract_config_path = ModelCatalog.get_full_path_configs("/dd/conf_tesseract.yaml")
+            tess = TesseractOcrDetector(tesseract_config_path)
+            ocr_service = TextExtractionService(tess)
+
+            # hf tokenizer and token classifier
+            tokenizer = LayoutLMTokenizer.from_pretrained("mrm8488/layoutlm-finetuned-funsd")
+            layoutlm = HFLayoutLmTokenClassifier("path/to/config.json","path/to/model.bin",
+                                                  categories_explicit= ['B-ANSWER', 'B-HEAD', 'B-QUESTION', 'E-ANSWER',
+                                                                        'E-HEAD', 'E-QUESTION', 'I-ANSWER', 'I-HEAD',
+                                                                        'I-QUESTION', 'O', 'S-ANSWER', 'S-HEAD',
+                                                                        'S-QUESTION'])
+
+            # token classification service
+            layoutlm_service = LMTokenClassifierService(tokenizer,layoutlm,image_to_layoutlm)
+
+            pipe = DoctectionPipe(pipeline_component_list=[ocr_service,layoutlm_service])
+
+            path = "path/to/some/form"
+            df = pipe.analyze(path=path)
+
+            for dp in df:
+                ...
     """
 
     def __init__(
         self,
-        categories_semantics: Optional[List[str]] = None,
-        categories_bio: Optional[List[str]] = None,
-        categories_explicit: Optional[List[str]] = None,
+        path_config_json: str,
+        path_weights: str,
+        categories_semantics: Optional[Sequence[str]] = None,
+        categories_bio: Optional[Sequence[str]] = None,
+        categories_explicit: Optional[Sequence[str]] = None,
     ):
         """
         :param categories_semantics: A dict with key (indices) and values (category names) for NER semantics, i.e. the
@@ -97,17 +127,22 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
             assert categories_semantics is not None
             assert categories_bio is not None
 
-        self.categories_semantics = categories_semantics
-        self.categories_bio = categories_bio
-        self.categories_ecplicit = categories_explicit
+        self.path_config_json = path_config_json
+        self.path_weights = path_weights
+        self.categories_semantics = copy(categories_semantics) if categories_semantics is not None else None
+        self.categories_bio = copy(categories_bio) if categories_bio is not None else None
+        self.categories_explicit = copy(categories_explicit) if categories_explicit is not None else None
 
         self._categories: Dict[int, str] = (
-            dict(enumerate(categories_explicit))
+            dict(enumerate(self.categories_explicit))  # type: ignore
             if categories_explicit is not None
             else self._categories_orig_to_categories(categories_semantics, categories_bio)  # type: ignore
         )
         self.device = set_torch_auto_device()
-        self.model = LayoutLMForTokenClassification.from_pretrained("mrm8488/layoutlm-finetuned-funsd")
+        config = PretrainedConfig.from_pretrained(pretrained_model_name_or_path=path_config_json)
+        self.model = LayoutLMForTokenClassification.from_pretrained(
+            pretrained_model_name_or_path=path_weights, config=config
+        )
 
     @classmethod
     def get_requirements(cls) -> List[Requirement]:
@@ -132,13 +167,20 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
         assert "boxes" in encodings
         assert "tokens" in encodings
 
+        assert isinstance(encodings["ids"], list)
+        assert isinstance(encodings["input_ids"], torch.Tensor)
+        assert isinstance(encodings["attention_mask"], torch.Tensor)
+        assert isinstance(encodings["token_type_ids"], torch.Tensor)
+        assert isinstance(encodings["boxes"], torch.Tensor)
+        assert isinstance(encodings["tokens"], list)
+
         results = predict_token_classes(
-            encodings["ids"],  # type: ignore
-            encodings["input_ids"],  # type: ignore
-            encodings["attention_mask"],  # type: ignore
-            encodings["token_type_ids"],  # type: ignore
-            encodings["boxes"],  # type: ignore
-            encodings["tokens"],  # type: ignore
+            encodings["ids"],
+            encodings["input_ids"],
+            encodings["attention_mask"],
+            encodings["token_type_ids"],
+            encodings["boxes"],
+            encodings["tokens"],
             self.model,
         )
 
@@ -167,4 +209,10 @@ class HFLayoutLmTokenClassifier(LMTokenClassifier):
         return self._categories
 
     def clone(self) -> PredictorBase:
-        return self.__class__(self.categories_semantics, self.categories_bio, self.categories_ecplicit)
+        return self.__class__(
+            self.path_config_json,
+            self.path_weights,
+            self.categories_semantics,
+            self.categories_bio,
+            self.categories_explicit,
+        )
