@@ -111,6 +111,7 @@ def image_to_dict(image: ImageType, lang: str, config: str) -> Dict[str, List[Un
     - reading the .tsv file and returning the results as dict.
 
     Requires Tesseract 3.05+
+
     :param image: Image in np.array.
     :param lang: String of language
     :param config: string of configs
@@ -136,6 +137,7 @@ def image_to_dict(image: ImageType, lang: str, config: str) -> Dict[str, List[Un
         str_col_idx = -1
         str_col_idx += length
 
+        val: Union[str, int]
         for i, head in enumerate(header):
             result[head] = []
             for row in rows:
@@ -144,7 +146,7 @@ def image_to_dict(image: ImageType, lang: str, config: str) -> Dict[str, List[Un
 
                 val = row[i]
                 if row[i].isdigit() and i != -1 and head != "text":
-                    val = int(row[i])  # type: ignore
+                    val = int(row[i])
                 elif head == "text":
                     val = str(row[i])
                 result[head].append(val)
@@ -211,10 +213,11 @@ def predict_text(np_img: ImageType, supported_languages: str, text_lines: bool,
         results["block_num"],
         results["line_num"],
     ):
-        if int(caption[4]) != -1:
+        score = float(caption[4])
+        if int(score) != -1:
             word = DetectionResult(
                 box=[caption[0], caption[1], caption[0] + caption[2], caption[1] + caption[3]],
-                score=caption[4] / 100,
+                score=score / 100,
                 text=caption[5],
                 block=str(caption[6]),
                 line=str(caption[7]),
@@ -227,7 +230,7 @@ def predict_text(np_img: ImageType, supported_languages: str, text_lines: bool,
     return all_results
 
 
-class TesseractOcrDetector(ObjectDetector):  # pylint: disable=R0903
+class TesseractOcrDetector(ObjectDetector):
     """
     Text object detector based on Tesseracts OCR engine. Note that tesseract has to be installed separately.
 
@@ -238,6 +241,28 @@ class TesseractOcrDetector(ObjectDetector):  # pylint: disable=R0903
 
     All configuration options that are available via pytesseract can be given via the configuration. The best overview
     can be found at https://pypi.org/project/pytesseract/.
+
+    .. code-block:: python
+
+        tesseract_config_path = ModelCatalog.get_full_path_configs("dd/conf_tesseract.yaml")
+        ocr_detector = TesseractOcrDetector(tesseract_config_path)
+
+        detection_result = ocr_detector.predict(bgr_image_as_np_array)
+
+    To use it within a pipeline
+
+    .. code-block:: python
+
+        tesseract_config_path = ModelCatalog.get_full_path_configs("dd/conf_tesseract.yaml")
+        ocr_detector = TesseractOcrDetector(tesseract_config_path)
+
+        text_extract = TextExtractionService(ocr_detector)
+        pipe = DoctectionPipe([text_extract])
+
+        df = pipe.analyze(path="path/to/dir")
+
+        for dp in df:
+            ...
     """
 
     def __init__(
