@@ -21,13 +21,13 @@ builder method of a dataset.
 """
 
 from collections import defaultdict
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Mapping, Optional, Sequence, Union
 
 from ..datapoint.image import Image
-from .maputils import cur
+from .maputils import curry
 
 
-@cur  # type: ignore
+@curry
 def cat_to_sub_cat(
     dp: Image, categories_dict_names_as_key: Dict[str, str], cat_to_sub_cat_dict: Optional[Dict[str, str]] = None
 ) -> Image:
@@ -55,7 +55,7 @@ def cat_to_sub_cat(
     return dp
 
 
-@cur  # type: ignore
+@curry
 def re_assign_cat_ids(dp: Image, categories_dict_name_as_key: Dict[str, str]) -> Image:
     """
     Re-assigning category ids is sometimes necessary to align with categories of the :class:`DatasetCategories` . E.g.
@@ -73,7 +73,7 @@ def re_assign_cat_ids(dp: Image, categories_dict_name_as_key: Dict[str, str]) ->
     return dp
 
 
-@cur  # type: ignore
+@curry
 def filter_cat(dp: Image, categories_as_list_filtered: List[str], categories_as_list_unfiltered: List[str]) -> Image:
     """
     Filters category annotations based on the on a list of categories to be kept and a list of all possible
@@ -89,40 +89,40 @@ def filter_cat(dp: Image, categories_as_list_filtered: List[str], categories_as_
 
     cats_to_remove_list = [cat for cat in categories_as_list_unfiltered if cat not in categories_as_list_filtered]
 
-    remove_cats_mapper = remove_cats(category_names=cats_to_remove_list)  # type: ignore # pylint: disable=E1120  # 259
+    remove_cats_mapper = remove_cats(category_names=cats_to_remove_list)  # pylint: disable=E1120  # 259
     dp = remove_cats_mapper(dp)
 
     categories_dict_name_as_key = {v: str(k) for k, v in enumerate(categories_as_list_filtered, 1)}
     re_assign_cat_ids_mapper = re_assign_cat_ids(  # pylint: disable=E1120
-        categories_dict_name_as_key=categories_dict_name_as_key  # type: ignore
+        categories_dict_name_as_key=categories_dict_name_as_key
     )
     dp = re_assign_cat_ids_mapper(dp)
 
     return dp
 
 
-@cur  # type: ignore
+@curry
 def image_to_cat_id(
     dp: Image,
-    category_names: Optional[Union[str, List[str]]] = None,
-    sub_category_names: Optional[Union[Dict[str, str], Dict[str, List[str]]]] = None,
+    category_names: Optional[Union[str, Sequence[str]]] = None,
+    sub_category_names: Optional[Union[Mapping[str, str], Mapping[str, Sequence[str]]]] = None,
 ) -> Dict[str, List[int]]:
     """
     Extracts all category_ids with given names into a defaultdict with names as keys.
 
     **Example:**
 
-              dp contains annotations
+        dp contains annotations
 
-              {'1', '2', '1', '1', '2', '3'}
+        `{'1', '2', '1', '1', '2', '3'}`
 
-              where
+        where
 
-              {'foo': '1', 'bak': '2', 'baz': '3'}.
+        `{'foo': '1', 'bak': '2', 'baz': '3'}`.
 
-              The returned value will be
+        The returned value will be
 
-              {'foo':['1', '1', '1'], 'bak':[ '2', '2'], 'baz':[ '3']}.
+        `{'foo':['1', '1', '1'], 'bak':[ '2', '2'], 'baz':[ '3']}`.
 
     :param dp: Image datapoint
     :param category_names: A list of category names
@@ -136,21 +136,19 @@ def image_to_cat_id(
     if not category_names:
         category_names = []
 
-    if sub_category_names is None:
-        sub_category_names = {}  # type: ignore
+    tmp_sub_category_names: Dict[str, Sequence[str]] = {}
 
-    assert sub_category_names is not None
-
-    for key, val in sub_category_names.items():
-        if isinstance(val, str):
-            val = [val]
-            sub_category_names[key] = val  # type: ignore
+    if sub_category_names is not None:
+        for key, val in sub_category_names.items():
+            if isinstance(val, str):
+                val = [val]
+            tmp_sub_category_names[key] = val
 
     for ann in dp.get_annotation_iter():
         if ann.category_name in category_names:
             cat_container[ann.category_name].append(int(ann.category_id))
-        if ann.category_name in sub_category_names.keys():
-            for sub_cat_name in sub_category_names[ann.category_name]:
+        if ann.category_name in tmp_sub_category_names:
+            for sub_cat_name in tmp_sub_category_names[ann.category_name]:
                 sub_cat = ann.get_sub_category(sub_cat_name)
                 if sub_cat is not None:
                     cat_container[sub_cat_name].append(int(sub_cat.category_id))
@@ -158,11 +156,11 @@ def image_to_cat_id(
     return cat_container
 
 
-@cur  # type: ignore
+@curry
 def remove_cats(
     dp: Image,
-    category_names: Optional[Union[str, List[str]]] = None,
-    sub_categories: Optional[Union[Dict[str, str], Dict[str, List[str]]]] = None,
+    category_names: Optional[Union[str, Sequence[str]]] = None,
+    sub_categories: Optional[Union[Mapping[str, str], Mapping[str, Sequence[str]]]] = None,
 ) -> Image:
     """
     Remove categories according to given category names or sub category names. Note that these will change the container
@@ -181,15 +179,15 @@ def remove_cats(
         category_names = []
 
     if sub_categories is None:
-        sub_categories = {}  # type: ignore
+        sub_categories = {}
 
     anns_to_remove = []
 
     for ann in dp.get_annotation_iter():
         if ann.category_name in category_names:
             anns_to_remove.append(ann)
-        if ann.category_name in sub_categories.keys():  # type: ignore
-            sub_cats_to_remove = sub_categories[ann.category_name]  # type: ignore
+        if ann.category_name in sub_categories.keys():
+            sub_cats_to_remove = sub_categories[ann.category_name]
             if isinstance(sub_cats_to_remove, str):
                 sub_cats_to_remove = [sub_cats_to_remove]
             for sub_cat in sub_cats_to_remove:
