@@ -21,16 +21,16 @@ Utility functions related to mapping tasks
 import functools
 import itertools
 from types import TracebackType
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, Optional, Sequence, Union
 
 import numpy as np
 from tabulate import tabulate
 from termcolor import colored
 
-from ..utils.detection_types import BaseExceptionType, MapFunc
+from ..utils.detection_types import DP, BaseExceptionType, S, T
 from ..utils.logger import log_once, logger
 
-__all__ = ["MappingContextManager", "DefaultMapper", "maybe_get_fake_score", "LabelSummarizer", "cur"]
+__all__ = ["MappingContextManager", "DefaultMapper", "maybe_get_fake_score", "LabelSummarizer", "curry"]
 
 
 class MappingContextManager:
@@ -39,11 +39,11 @@ class MappingContextManager:
     context if an exception has been thrown.
     """
 
-    def __init__(self, dp_name: Optional[str] = "") -> None:
+    def __init__(self, dp_name: Optional[str] = None) -> None:
         """
         :param dp_name: A name for the datapoint to be mapped
         """
-        self.dp_name = dp_name
+        self.dp_name = dp_name if dp_name is not None else ""
         self.context_error = True
 
     def __enter__(self) -> "MappingContextManager":
@@ -80,7 +80,7 @@ class DefaultMapper:  # pylint: disable=R0903
     https://stackoverflow.com/questions/36314/what-is-currying
     """
 
-    def __init__(self, func: Callable[[Any], Any], *args: Any, **kwargs: Any) -> None:
+    def __init__(self, func: Callable[[DP, S], T], *args: Any, **kwargs: Any) -> None:
         """
         :param func: A mapping function
         :param args: Default args to pass to the function
@@ -98,7 +98,7 @@ class DefaultMapper:  # pylint: disable=R0903
         return self.func(dp, *self.argument_args, **self.argument_kwargs)
 
 
-def cur(func: MapFunc) -> DefaultMapper:
+def curry(func: Callable[..., T]) -> Callable[..., Callable[[DP], T]]:
     """
     Decorator for converting functions that map
 
@@ -109,14 +109,18 @@ def cur(func: MapFunc) -> DefaultMapper:
 
     **Example:**
 
-               @cur
-               def json_to_image(dp, config_arg_1, config_arg_2,...) -> Image:
-               ...
+        .. code-block:: python
 
-               can be applied like:
+            @curry
+            def json_to_image(dp, config_arg_1, config_arg_2,...) -> Image:
+            ...
 
-               df = ...
-               df = MapData(df,json_to_image(config_arg_1=val_1,config_arg_2=val_2))
+        can be applied like:
+
+        .. code-block:: python
+
+            df = ...
+            df = MapData(df,json_to_image(config_arg_1=val_1,config_arg_2=val_2))
 
     :param func: A callable [[:class:`Image`],[Any]] -> [:class:`Image`]
     :return: A DefaultMapper
@@ -124,10 +128,9 @@ def cur(func: MapFunc) -> DefaultMapper:
 
     @functools.wraps(func)
     def wrap(*args: Any, **kwargs: Any) -> DefaultMapper:
-        ret = DefaultMapper(func, *args, **kwargs)
-        return ret
+        return DefaultMapper(func, *args, **kwargs)
 
-    return wrap  # type: ignore
+    return wrap
 
 
 def maybe_get_fake_score(add_fake_score: bool) -> Optional[float]:
@@ -145,6 +148,16 @@ def maybe_get_fake_score(add_fake_score: bool) -> Optional[float]:
 class LabelSummarizer:
     """
     A class for generating label statistics. Useful, when mapping and generating a SummaryAnnotation.
+
+    .. code-block:: python
+
+        summarizer = LabelSummarizer({"1": "label_1","2":"label_2"})
+
+        for dp in some_dataflow:
+            summarizer.dump(dp["label_id"])
+
+        summarizer.print_summary_histogram()
+
     """
 
     def __init__(self, categories: Dict[str, str]) -> None:
@@ -156,14 +169,14 @@ class LabelSummarizer:
         self.hist_bins = np.arange(1, cat_numbers + 2)
         self.summary = np.zeros(cat_numbers)
 
-    def dump(self, item: Union[List[Union[str, int]], str, int]) -> None:
+    def dump(self, item: Union[Sequence[Union[str, int]], str, int]) -> None:
         """
         Dump a category number
 
         :param item: A category number.
         """
-        item = np.asarray(item, dtype="int8")  # type: ignore
-        self.summary += np.histogram(item, bins=self.hist_bins)[0]
+        np_item = np.asarray(item, dtype="int8")
+        self.summary += np.histogram(np_item, bins=self.hist_bins)[0]
 
     def get_summary(self) -> Dict[str, np.int32]:
         """
@@ -171,11 +184,16 @@ class LabelSummarizer:
         """
         return dict(list(zip(self.categories.keys(), self.summary.astype(np.int32))))
 
-    def print_summary_histogram(self) -> None:
+    def print_summary_histogram(self, dd_logic: bool = True) -> None:
         """
         Prints a summary from all dumps.
+
+        :param dd_logic: Follow dd category convention when printing histogram (last background bucket omitted).
         """
-        data = list(itertools.chain(*[[self.categories[str(i + 1)], v] for i, v in enumerate(self.summary[:-1])]))
+        if dd_logic:
+            data = list(itertools.chain(*[[self.categories[str(i)], v] for i, v in enumerate(self.summary,1)]))
+        else:
+            data = list(itertools.chain(*[[self.categories[str(i + 1)], v] for i, v in enumerate(self.summary[:-1])]))
         num_columns = min(6, len(data))
         total_img_anns = sum(data[1::2])
         data.extend([None] * ((num_columns - len(data) % num_columns) % num_columns))
