@@ -21,8 +21,6 @@ Module for mapping Images or exported dictionaries into page formats
 from itertools import chain
 from typing import List, Optional, Tuple
 
-from numpy import float32
-
 from ..datapoint.annotation import ImageAnnotation
 from ..datapoint.convert import convert_np_array_to_b64
 from ..datapoint.doc import Cell, LayoutSegment, Page, Table, TableSegment
@@ -33,10 +31,6 @@ from ..utils.settings import names
 __all__ = ["to_page", "page_dict_to_page"]
 
 
-def _to_float(value: Optional[float32]) -> float:
-    return float(value) if value is not None else 0.0
-
-
 def _to_table_segment(dp: Image, annotation: ImageAnnotation) -> TableSegment:
     if annotation.image is not None:
         bounding_box = annotation.image.get_embedding(dp.image_id)
@@ -44,13 +38,13 @@ def _to_table_segment(dp: Image, annotation: ImageAnnotation) -> TableSegment:
         bounding_box = annotation.bounding_box
 
     if not bounding_box.absolute_coords:
-        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True, output="box")
+        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True)
 
     return TableSegment(
         annotation.annotation_id,
         bounding_box.to_list(mode="xyxy"),
         annotation.category_name,
-        _to_float(annotation.score),  # type: ignore
+        annotation.score,
     )
 
 
@@ -66,7 +60,7 @@ def _to_cell(dp: Image, annotation: ImageAnnotation, text_container: str) -> Tup
         bounding_box = annotation.bounding_box
 
     if not bounding_box.absolute_coords:
-        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True, output="box")
+        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True)
 
     return (
         Cell(
@@ -77,7 +71,7 @@ def _to_cell(dp: Image, annotation: ImageAnnotation, text_container: str) -> Tup
             int(annotation.get_sub_category(names.C.CN).category_id),
             int(annotation.get_sub_category(names.C.RS).category_id),
             int(annotation.get_sub_category(names.C.CS).category_id),
-            _to_float(annotation.score),  # type: ignore
+            annotation.score,
         ),
         text,
     )
@@ -100,6 +94,10 @@ def _to_table(dp: Image, annotation: ImageAnnotation, text_container: str) -> Ta
             ):
                 number_rows = int(annotation.image.summary.get_sub_category(names.C.NR).category_id)
                 number_cols = int(annotation.image.summary.get_sub_category(names.C.NC).category_id)
+        else:
+            if cell_anns:
+                number_rows = max([int(cell.get_sub_category(names.C.RN).category_id) for cell in cell_anns])
+                number_cols = max([int(cell.get_sub_category(names.C.CN).category_id) for cell in cell_anns])
 
     # cell
     for cell_ann in cell_anns:
@@ -127,7 +125,7 @@ def _to_table(dp: Image, annotation: ImageAnnotation, text_container: str) -> Ta
         bounding_box = annotation.bounding_box
 
     if not bounding_box.absolute_coords:
-        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True, output="box")
+        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True)
 
     return Table(
         annotation.annotation_id,
@@ -137,7 +135,7 @@ def _to_table(dp: Image, annotation: ImageAnnotation, text_container: str) -> Ta
         number_rows,
         number_cols,
         html,
-        _to_float(annotation.score),  # type: ignore
+        annotation.score,
     )
 
 
@@ -159,14 +157,14 @@ def _to_layout_segment(dp: Image, annotation: ImageAnnotation, text_container: s
     else:
         bounding_box = annotation.bounding_box
     if not bounding_box.absolute_coords:
-        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True, output="box")
+        bounding_box = bounding_box.transform(dp.width, dp.height, absolute_coords=True)
     return LayoutSegment(
         annotation.annotation_id,
         bounding_box.to_list(mode="xyxy"),
         annotation.category_name,
         reading_order,
         text,
-        _to_float(annotation.score),  # type: ignore
+        annotation.score,
     )
 
 
