@@ -23,7 +23,7 @@ from typing import List, Optional, Union
 
 import numpy as np
 
-from ..dataflow import DataFlow, MapData  # type: ignore
+from ..dataflow import DataFlow, MapData
 from ..datapoint.doc import Page
 from ..datapoint.image import Image
 from ..mapper.maputils import MappingContextManager
@@ -31,8 +31,35 @@ from ..mapper.match import match_anns_by_intersection
 from ..mapper.pagestruct import to_page
 from ..utils.settings import names
 from .base import PipelineComponent
+from .registry import pipeline_component_registry
 
 
+@pipeline_component_registry.register("ImageCroppingService")
+class ImageCroppingService(PipelineComponent):
+    """
+    Crop sub images given by bounding boxes of some annotations. This service is not necessary for
+    :class::`ImageLayoutService` and is more intended for saved files where sub images are
+    generally not stored.
+    """
+
+    def __init__(self, category_names: Union[str, List[str]]):
+        """
+        :param category_names: A single name or a list of category names to crop
+        """
+        super().__init__(None)
+        if isinstance(category_names, str):
+            category_names = [category_names]
+        self.category_names = category_names
+
+    def serve(self, dp: Image) -> None:
+        for ann in dp.get_annotation(category_names=self.category_names):
+            dp.image_ann_to_image(ann.annotation_id, crop_image=True)
+
+    def clone(self) -> "PipelineComponent":
+        return self.__class__(self.category_names)
+
+
+@pipeline_component_registry.register("MatchingService")
 class MatchingService(PipelineComponent):
     """
     Objects of two object classes can be assigned to one another by determining their pairwise average. If this is above
@@ -41,6 +68,17 @@ class MatchingService(PipelineComponent):
     relation is created in the parent class if the conditions are met.
 
     Either iou (intersection-over-union) or ioa (intersection-over-area) can be selected as the matching rule.
+
+        .. code-block:: python
+
+            # the following will assign word annotations to text and title annotation, provided that their ioa-threshold
+            # is above 0.7. words below that threshold will not be assigned.
+
+            match = MatchingService(parent_categories=["TEXT","TITLE"],child_categories="WORD",matching_rule="ioa",
+                                    threshold=0.7)
+
+            # Assigning means that text and title annotation will receive a relationship called "CHILD" which is a list
+              of annotation ids of mapped words.
     """
 
     def __init__(
@@ -48,7 +86,7 @@ class MatchingService(PipelineComponent):
         parent_categories: Union[str, List[str]],
         child_categories: Union[str, List[str]],
         matching_rule: str,
-        threshold: Optional[np.float32] = None,
+        threshold: float,
     ) -> None:
         """
         :param parent_categories: list of categories to be used a for parent class. Will generate a child-relationship
@@ -75,7 +113,7 @@ class MatchingService(PipelineComponent):
             parent_ann_category_names=self.parent_categories,
             child_ann_category_names=self.child_categories,
             matching_rule=self.matching_rule,
-            threshold=self.threshold,  # type: ignore
+            threshold=self.threshold,
             max_parent_only=True,
         )
 
@@ -89,6 +127,7 @@ class MatchingService(PipelineComponent):
         return self.__class__(self.parent_categories, self.child_categories, self.matching_rule, self.threshold)
 
 
+@pipeline_component_registry.register("PageParsingService")
 class PageParsingService:
     """
     A "pseudo" pipeline component that can be added to a pipeline to convert Images into Page formats. It allows a
