@@ -21,17 +21,21 @@ Module for multithreading tasks
 
 import itertools
 import queue
-import sys
 from concurrent.futures import ThreadPoolExecutor
 from contextlib import ExitStack
-from typing import Callable, List, Optional, Union
+from typing import TYPE_CHECKING, Callable, List, Optional, Sequence, Union
 
 import tqdm  # type: ignore
 
 from ..dataflow import DataFlow
 from ..datapoint.image import Image
 from ..utils.tqdm import get_tqdm
-from .base import PipelineComponent
+from .base import PipelineComponent, PredictorPipelineComponent
+
+if TYPE_CHECKING:
+    QueueType = queue.Queue[Image]  # pylint: disable=E1136
+else:
+    QueueType = queue.Queue
 
 
 class MultiThreadPipelineComponent:
@@ -49,11 +53,25 @@ class MultiThreadPipelineComponent:
     also be transferred as a function. These tasks are also assigned to the threads.
 
     Note that the order in the dataflow and when returning lists is generally is no longer retained.
+
+    .. code-block:: python
+
+        some_component = SubImageLayoutService(some_predictor, some_category)
+        some_component:clone = some_component.clone()
+
+
+        multi_thread_comp = MultiThreadPipelineComponent(pipeline_components=[some_component,some_component_clone],
+                                                         pre_proc_func=maybe_load_image,
+                                                         post_proc_func=maybe_remove_image)
+
+        multi_thread_comp.put_task(some_dataflow)
+        output_list = multi_thread_comp.start()
+
     """
 
     def __init__(
         self,
-        pipeline_components: List[PipelineComponent],
+        pipeline_components: Sequence[PredictorPipelineComponent],
         pre_proc_func: Optional[Callable[[Image], Image]] = None,
         post_proc_func: Optional[Callable[[Image], Image]] = None,
         max_datapoints: Optional[int] = None,
@@ -70,7 +88,7 @@ class MultiThreadPipelineComponent:
         """
 
         self.pipe_components = pipeline_components
-        self.input_queue: queue.Queue = queue.Queue()  # type: ignore
+        self.input_queue: QueueType = queue.Queue()
         self.pre_proc_func = pre_proc_func
         self.post_proc_func = post_proc_func
         self.max_datapoints = max_datapoints
@@ -92,10 +110,9 @@ class MultiThreadPipelineComponent:
 
         :return: A list of Images
         """
-        kwargs = {"thread_name_prefix": "EvalWorker"} if sys.version_info.minor >= 6 else {}
-        with ThreadPoolExecutor(max_workers=len(self.pipe_components), **kwargs) as executor, tqdm.tqdm(  # type: ignore
-            total=self.input_queue.qsize()
-        ) as pbar:
+        with ThreadPoolExecutor(
+            max_workers=len(self.pipe_components), thread_name_prefix="EvalWorker"
+        ) as executor, tqdm.tqdm(total=self.input_queue.qsize()) as pbar:
             futures = []
             for component in self.pipe_components:
                 futures.append(
@@ -113,7 +130,7 @@ class MultiThreadPipelineComponent:
 
     @staticmethod
     def _thread_predict_on_queue(
-        input_queue: queue.Queue,  # type: ignore
+        input_queue: QueueType,
         component: PipelineComponent,
         tqdm_bar: Optional[tqdm.tqdm] = None,
         pre_proc_func: Optional[Callable[[Image], Image]] = None,
