@@ -20,13 +20,15 @@ Module for pipeline with Tensorpack predictors
 """
 
 import os
-from typing import Dict, List, Optional, Union
+from pathlib import Path
+from typing import Dict, List, Optional, Sequence, Union
 
-from ..dataflow import DataFlow, MapData  # type: ignore
+from ..dataflow import DataFlow, MapData
 from ..dataflow.custom_serialize import SerializerFiles, SerializerPdfDoc
 from ..datapoint.image import Image
-from ..mapper.maputils import cur
+from ..mapper.maputils import curry
 from ..mapper.misc import to_image
+from ..utils.detection_types import Pathlike
 from ..utils.fs import maybe_path_or_pdf
 from ..utils.logger import logger
 from ..utils.settings import names
@@ -34,19 +36,20 @@ from .base import Pipeline, PipelineComponent, PredictorPipelineComponent
 from .common import PageParsingService
 
 
-class DoctectionPipe(Pipeline):  # pylint: disable=W0221
+class DoctectionPipe(Pipeline):
     """
     Prototype for a document layout pipeline. Contains implementation for loading document types (images in directory,
     single PDF document, dataflow from datasets), conversions in dataflows and building a pipeline.
 
-    See deepdoctection.analyzer.dd for a concrete implementation.
+    See `deepdoctection.analyzer.dd` for a concrete implementation.
 
     See also the explanations in :class:`base.Pipeline`
+
+
     """
 
-    def __init__(
-        self, pipeline_component_list: List[Union[PipelineComponent, PredictorPipelineComponent, PageParsingService]]
-    ):
+    def __init__(self, pipeline_component_list: List[PipelineComponent]):
+        self.page_parser: PageParsingService
         if isinstance(pipeline_component_list[-1], PageParsingService):
             self.page_parser = pipeline_component_list.pop()
         else:
@@ -58,17 +61,20 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
         assert all(
             isinstance(element, (PipelineComponent, PredictorPipelineComponent)) for element in pipeline_component_list
         )
-        super().__init__(pipeline_component_list)  # type: ignore
+        super().__init__(pipeline_component_list)
 
-    def _entry(self, **kwargs: str) -> DataFlow:
+    def _entry(self, **kwargs: Union[str, DataFlow, bool, int, Pathlike, Union[str, List[str]]]) -> DataFlow:
         dataset_dataflow = kwargs.get("dataset_dataflow")
+
         path = kwargs.get("path")
         assert path is not None or dataset_dataflow is not None, "pass either path or dataset_dataflow as argument"
+
         shuffle = kwargs.get("shuffle", False)
         assert isinstance(shuffle, bool)
 
         doc_path = None
         if path:
+            assert isinstance(path, (str, Path))
             path_type = maybe_path_or_pdf(path)
             if path_type == 2:
                 doc_path = path
@@ -77,22 +83,34 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
                 raise ValueError("Pass only a path to a directory or to a pdf file")
 
         file_type = kwargs.get("file_type", [".jpg", ".png", ".tif"])
-        max_datapoints = kwargs.get("max_datapoints")
 
-        if isinstance(path, str):
+        max_datapoints = kwargs.get("max_datapoints")
+        assert isinstance(max_datapoints, (int, type(None)))
+
+        if isinstance(path, (str, Path)):
+            assert isinstance(file_type, (str, list))
             df = DoctectionPipe.path_to_dataflow(path, file_type, shuffle=shuffle)
-        if isinstance(doc_path, str):
+        if isinstance(doc_path, (str, Path)):
             df = DoctectionPipe.doc_to_dataflow(
                 path=doc_path, max_datapoints=int(max_datapoints) if max_datapoints is not None else None
             )
         if dataset_dataflow is not None:
             df = dataset_dataflow
 
+        def _proto_process(dp: Image) -> Image:
+            logger.info("processing %s", dp.file_name)
+            return dp
+
+        df = MapData(df, _proto_process)
+
         return df
 
     @staticmethod
     def path_to_dataflow(
-        path: str, file_type: Union[str, List[str]], max_datapoints: Optional[int] = None, shuffle: bool = False
+        path: Pathlike,
+        file_type: Union[str, Sequence[str]],
+        max_datapoints: Optional[int] = None,
+        shuffle: bool = False,
     ) -> DataFlow:
         """
         Processing method for directories
@@ -108,15 +126,14 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
 
         def _to_image(dp: str) -> Optional[Image]:
             _, file_name = os.path.split(dp)
-            logger.info("processing %s", file_name)
-            dp = {"file_name": file_name, "location": dp}  # type: ignore
-            return to_image(dp)
+            dp_dict = {"file_name": file_name, "location": dp}
+            return to_image(dp_dict)
 
         df = MapData(df, _to_image)
         return df
 
     @staticmethod
-    def doc_to_dataflow(path: str, max_datapoints: Optional[int] = None) -> DataFlow:
+    def doc_to_dataflow(path: Pathlike, max_datapoints: Optional[int] = None) -> DataFlow:
         """
         Processing method for documents
 
@@ -127,12 +144,11 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
         assert os.path.isfile(path), f"{path} not a file"
         df = SerializerPdfDoc.load(path, max_datapoints=max_datapoints)
 
-        @cur  # type: ignore
+        @curry
         def _to_image(dp: Union[str, Dict[str, Union[str, bytes]]], dpi: Optional[int] = None) -> Optional[Image]:
-            logger.info("processing %s", dp["file_name"])  # type: ignore
             return to_image(dp, dpi)
 
-        df = MapData(df, _to_image(dpi=300))  # type: ignore  # pylint: disable=E1120
+        df = MapData(df, _to_image(dpi=300))  # pylint: disable=E1120
         return df
 
     def dataflow_to_page(self, df: DataFlow) -> DataFlow:
@@ -144,7 +160,7 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
         """
         return self.page_parser.predict_dataflow(df)
 
-    def analyze(self, **kwargs: str) -> DataFlow:
+    def analyze(self, **kwargs: Union[str, DataFlow, bool, int, Pathlike, Union[str, List[str]]]) -> DataFlow:
         """
         :param kwargs key dataset_dataflow: Transfer a dataflow of a dataset via its dataflow builder
         :param kwargs key path: A path to a directory in which either image documents or pdf files are located. It is
