@@ -33,6 +33,7 @@ from ..datapoint.image import Image
 from ..extern.base import DetectionResult
 from ..utils.settings import names
 from .base import PipelineComponent
+from .registry import pipeline_component_registry
 
 __all__ = ["TableSegmentationRefinementService"]
 
@@ -329,6 +330,7 @@ def generate_html_string(table: ImageAnnotation) -> List[str]:
     return _html_table(table_list, cells_ann_list, number_of_rows, number_of_cols)
 
 
+@pipeline_component_registry.register("TableSegmentationRefinementService")
 class TableSegmentationRefinementService(PipelineComponent):
     """
     Refinement of the cell segmentation. The aim of this component is to create a table structure so that an HTML
@@ -359,6 +361,27 @@ class TableSegmentationRefinementService(PipelineComponent):
     The table consists of one row and two columns. The upper cells belong together with the lower cell.
     However, this means that all cells must be merged with one another so that the table only consists of one cell
     after the refinement process.
+
+    **Example**
+
+        .. code-block:: python
+
+            layout = ImageLayoutService(layout_detector, to_image=True, crop_image=True)
+            cell = SubImageLayoutService(cell_detector, "TABLE")
+            row_col = SubImageLayoutService(row_col_detector, "TABLE")
+            table_segmentation = TableSegmentationService("ioa",0.9,0.8,True,0.0001,0.0001)
+            table_segmentation_refinement = TableSegmentationRefinementService()
+
+            table_recognition_pipe = DoctectionPipe([layout,
+                                                     cell,
+                                                     row_col,
+                                                     table_segmentation,
+                                                     table_segmentation_refinement])
+            df = pipe.analyze(path="path/to/document.pdf")
+
+            for dp in df:
+                ...
+
     """
 
     def __init__(self) -> None:
@@ -401,11 +424,12 @@ class TableSegmentationRefinementService(PipelineComponent):
             number_of_cols = max([int(cell.get_sub_category(names.C.CN).category_id) for cell in cells])
             max_row_span = max([int(cell.get_sub_category(names.C.RS).category_id) for cell in cells])
             max_col_span = max([int(cell.get_sub_category(names.C.CS).category_id) for cell in cells])
-            self.dp_manager.set_summary_annotation(names.C.NR, number_of_rows, table.annotation_id)
-            self.dp_manager.set_summary_annotation(names.C.NC, number_of_cols, table.annotation_id)
-            self.dp_manager.set_summary_annotation(names.C.NRS, max_row_span, table.annotation_id)
-            self.dp_manager.set_summary_annotation(names.C.NCS, max_col_span, table.annotation_id)
+            self.dp_manager.set_summary_annotation(names.C.NR, number_of_rows, annotation_id=table.annotation_id)
+            self.dp_manager.set_summary_annotation(names.C.NC, number_of_cols, annotation_id=table.annotation_id)
+            self.dp_manager.set_summary_annotation(names.C.NRS, max_row_span, annotation_id=table.annotation_id)
+            self.dp_manager.set_summary_annotation(names.C.NCS, max_col_span, annotation_id=table.annotation_id)
             html = generate_html_string(table)
-            self.dp_manager.set_container_annotation(
-                names.C.HTAB, -1, names.C.HTAB, table.annotation_id, html  # type: ignore
-            )
+            self.dp_manager.set_container_annotation(names.C.HTAB, -1, names.C.HTAB, table.annotation_id, html)
+
+    def clone(self) -> PipelineComponent:
+        return self.__class__()
