@@ -25,15 +25,15 @@ from dataclasses import dataclass
 from typing import List, Optional, Union
 
 import numpy as np
-from numpy import float32
 
 from ..datapoint.annotation import ImageAnnotation
-from ..datapoint.box import BoundingBox, np_iou
+from ..datapoint.box import BoundingBox, iou
 from ..datapoint.image import Image
 from ..mapper.maputils import MappingContextManager
 from ..mapper.match import match_anns_by_intersection
 from ..utils.settings import names
 from .base import PipelineComponent
+from .registry import pipeline_component_registry
 
 __all__ = ["TableSegmentationService", "SegmentationResult"]
 
@@ -54,7 +54,7 @@ class SegmentationResult:
 def choose_items_by_iou(
     dp: Image,
     item_proposals: List[ImageAnnotation],
-    iou_threshold: np.float32,
+    iou_threshold: float,
     above_threshold: bool = True,
     reference_item_proposals: Optional[List[ImageAnnotation]] = None,
 ) -> Image:
@@ -69,15 +69,20 @@ def choose_items_by_iou(
     :param reference_item_proposals:
     """
     item_proposals_boxes = np.array(
-        [item.image.get_embedding(dp.image_id).to_list(mode="xyxy") for item in item_proposals]  # type: ignore
+        [
+            item.image.get_embedding(dp.image_id).to_list(mode="xyxy")
+            for item in item_proposals
+            if item.image is not None
+        ]
     )
 
     triangle_ind = None
     if reference_item_proposals is not None:
         reference_item_proposals_boxes = np.array(
             [
-                item.image.get_embedding(dp.image_id).to_list(mode="xyxy")  # type: ignore
+                item.image.get_embedding(dp.image_id).to_list(mode="xyxy")
                 for item in reference_item_proposals
+                if item.image is not None
             ]
         )
 
@@ -85,7 +90,7 @@ def choose_items_by_iou(
         reference_item_proposals_boxes = item_proposals_boxes
         triangle_ind = np.triu_indices(len(item_proposals))
 
-    iou_matrix = np_iou(item_proposals_boxes, reference_item_proposals_boxes)
+    iou_matrix = iou(item_proposals_boxes, reference_item_proposals_boxes)
 
     if triangle_ind is not None:
         iou_matrix[triangle_ind] = 0
@@ -110,8 +115,8 @@ def stretch_item_per_table(
     table: ImageAnnotation,
     row_name: str,
     col_name: str,
-    remove_iou_threshold_rows: np.float32,
-    remove_iou_threshold_cols: np.float32,
+    remove_iou_threshold_rows: float,
+    remove_iou_threshold_cols: float,
 ) -> Image:
     """
     Stretch rows horizontally and stretch columns vertically. Since the predictor usually does not predict a box for
@@ -207,8 +212,8 @@ def stretch_items(
     table_name: str,
     row_name: str,
     col_name: str,
-    remove_iou_threshold_rows: np.float32,
-    remove_iou_threshold_cols: np.float32,
+    remove_iou_threshold_rows: float,
+    remove_iou_threshold_cols: float,
 ) -> Image:
     """
     Stretch rows and columns from item detector to full table length and width. See :func:`stretch_item_per_table`
@@ -245,14 +250,14 @@ def _default_segment_table(cells: List[ImageAnnotation]) -> List[SegmentationRes
     return raw_table_segments
 
 
-def segment_table(  # pylint: disable=R0913, R0914
+def segment_table(
     dp: Image,
     table: ImageAnnotation,
     item_names: Union[str, List[str]],
     cell_names: Union[str, List[str]],
     segment_rule: str,
-    threshold_rows: Optional[np.float32] = None,
-    threshold_cols: Optional[np.float32] = None,
+    threshold_rows: float,
+    threshold_cols: float,
 ) -> List[SegmentationResult]:
     """
     Segments a table,i.e. produces for each cell a SegmentationResult. It uses numbered rows and columns that have to
@@ -279,7 +284,7 @@ def segment_table(  # pylint: disable=R0913, R0914
         item_names[0],
         cell_names,
         segment_rule,
-        threshold_rows,  # type: ignore
+        threshold_rows,
         True,
         child_ann_ids,
         child_ann_ids,
@@ -290,7 +295,7 @@ def segment_table(  # pylint: disable=R0913, R0914
         item_names[1],
         cell_names,
         segment_rule,
-        threshold_cols,  # type: ignore
+        threshold_cols,
         True,
         child_ann_ids,
         child_ann_ids,
@@ -335,6 +340,7 @@ def segment_table(  # pylint: disable=R0913, R0914
     return raw_table_segments
 
 
+@pipeline_component_registry.register("TableSegmentationService")
 class TableSegmentationService(PipelineComponent):
     """
     Table segmentation after successful cell detection. In addition, row and column detection must have been carried
@@ -362,14 +368,14 @@ class TableSegmentationService(PipelineComponent):
     If this should be excluded, class:`TableSegmentationRefinementService` can be used to merge cells.
     """
 
-    def __init__(  # pylint: disable=R0913
+    def __init__(
         self,
         segment_rule: str,
-        threshold_rows: np.float32,
-        threshold_cols: np.float32,
+        threshold_rows: float,
+        threshold_cols: float,
         tile_table_with_items: bool,
-        remove_iou_threshold_rows: np.float32,
-        remove_iou_threshold_cols: np.float32,
+        remove_iou_threshold_rows: float,
+        remove_iou_threshold_cols: float,
     ):
         """
         :param segment_rule: rule to assign cell to row, columns resp. must be either iou or ioa
@@ -413,13 +419,13 @@ class TableSegmentationService(PipelineComponent):
                 reference_items_proposals = dp.get_annotation(
                     category_names=self._cell_names, annotation_ids=item_ann_ids
                 )
-                dp = choose_items_by_iou(dp, items_proposals, float32(0.0001), False, reference_items_proposals)
+                dp = choose_items_by_iou(dp, items_proposals, 0.0001, False, reference_items_proposals)
 
                 # new query of items so that we only get active annotations
                 items = dp.get_annotation(category_names=item_name, annotation_ids=item_ann_ids)
                 items.sort(
                     key=lambda x: x.bounding_box.cx  # type: ignore
-                    if item_name == names.C.COL  # pylint: disable=C0301, W0640
+                    if item_name == names.C.COL  # pylint: disable=C0301
                     else x.bounding_box.cy  # type: ignore
                 )
                 for item_number, item in enumerate(items, 1):
@@ -448,3 +454,13 @@ class TableSegmentationService(PipelineComponent):
                 self.dp_manager.set_category_annotation(
                     names.C.CS, segment_result.cs, names.C.CS, segment_result.annotation_id
                 )
+
+    def clone(self) -> PipelineComponent:
+        return self.__class__(
+            self.segment_rule,
+            self.threshold_rows,
+            self.threshold_cols,
+            self.tile_table,
+            self.remove_iou_threshold_rows,
+            self.remove_iou_threshold_cols,
+        )
