@@ -19,7 +19,7 @@
 Module for text extraction pipeline component
 """
 from itertools import chain
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, List, Mapping, Optional, Sequence, Tuple, Union
 
 from ..datapoint.annotation import ImageAnnotation
 from ..datapoint.image import Image
@@ -28,10 +28,12 @@ from ..utils.detection_types import ImageType
 from ..utils.logger import logger
 from ..utils.settings import names
 from .base import PipelineComponent, PredictorPipelineComponent
+from .registry import pipeline_component_registry
 
 __all__ = ["TextExtractionService", "TextOrderService"]
 
 
+@pipeline_component_registry.register("TextExtractionService")
 class TextExtractionService(PredictorPipelineComponent):
     """
     Pipeline component for extracting text. Any detector can be selected, provided that it can evaluate a
@@ -48,13 +50,24 @@ class TextExtractionService(PredictorPipelineComponent):
     relation to text and ROI or in relation to text and the entire image. When selecting ROIs, only the selected
     categories are taken into account during processing. ROIs that are not selected are not presented to the
     detector.
+
+    .. code-block:: python
+
+        textract_predictor = TextractOcrDetector()
+        text_extract = TextExtractionService(textract_predictor)
+
+        pipe = DoctectionPipe([text_extract])
+        df = pipe.analyze(path="path/to/document.pdf")
+
+        for dp in df:
+            ...
     """
 
     def __init__(
         self,
         text_extract_detector: Union[ObjectDetector, PdfMiner, TextRecognizer],
-        extract_from_roi: Optional[Union[List[str], str]] = None,
-        category_id_mapping: Optional[Dict[int, int]] = None,
+        extract_from_roi: Optional[Union[Sequence[str], str]] = None,
+        category_id_mapping: Optional[Mapping[int, int]] = None,
     ):
         """
         :param text_extract_detector: ObjectDetector
@@ -109,7 +122,7 @@ class TextExtractionService(PredictorPipelineComponent):
                             names.C.TLINE, detect_result.line, names.C.TLINE, detect_ann_id
                         )
 
-    def get_text_rois(self, dp: Image) -> List[Union[Image, ImageAnnotation, List[ImageAnnotation]]]:
+    def get_text_rois(self, dp: Image) -> Sequence[Union[Image, ImageAnnotation, List[ImageAnnotation]]]:
         """
         Return image rois based on selected categories. As this selection makes only sense for specific text extractors
         (e.g. those who do proper OCR and do not mine from text from native pdfs) it will do some sanity checks.
@@ -119,7 +132,7 @@ class TextExtractionService(PredictorPipelineComponent):
         if self.extract_from_category:
             if self.predictor.accepts_batch:
                 return [dp.get_annotation(category_names=self.extract_from_category)]
-            return dp.get_annotation(category_names=self.extract_from_category)  # type: ignore
+            return dp.get_annotation(category_names=self.extract_from_category)
         return [dp]
 
     def get_predictor_input(
@@ -195,7 +208,7 @@ def _reading_columns(
             bounding_box = ann.bounding_box
 
         if bounding_box.absolute_coords:
-            rel_coords_box = bounding_box.transform(dp.width, dp.height, output="box")
+            rel_coords_box = bounding_box.transform(dp.width, dp.height)
         else:
             rel_coords_box = bounding_box
 
@@ -232,12 +245,13 @@ def _reading_columns(
     columns_dict = {
         idx: key[0] for idx, key in enumerate(sorted(columns_dict.items(), key=lambda it: it[1]["left"]))  # type:ignore
     }
-    reading_blocks = [(columns_dict[x[0]], x[1]) for x in reading_blocks]  # type:ignore
-    reading_blocks.sort(key=lambda x: x[0])
-    reading_blocks = [(idx + 1, block[1]) for idx, block in enumerate(reading_blocks)]
+    _blocks = [(columns_dict[x[0]], x[1]) for x in reading_blocks]
+    _blocks.sort(key=lambda x: x[0])  # type:ignore
+    reading_blocks = [(idx + 1, block[1]) for idx, block in enumerate(_blocks)]
     return reading_blocks
 
 
+@pipeline_component_registry.register("TextOrderService")
 class TextOrderService(PipelineComponent):
     """
     Reading order of words within floating text blocks as well as reading order of blocks within simple text blocks.
@@ -264,13 +278,20 @@ class TextOrderService(PipelineComponent):
     annotation per block, which saves the reading order of the block per page.
 
     The blocks are defined in :attr:`_floating_text_block_names` and text blocks in :attr:`_floating_text_block_names`.
+
+    .. code-block:: python
+
+        order = TextOrderService(text_container=names.C.WORD,
+                                 floating_text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST],
+                                 text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST, names.C.CELL,
+                                                   names.C.HEAD, names.C.BODY])
     """
 
     def __init__(
         self,
         text_container: str,
-        floating_text_block_names: Optional[Union[str, List[str]]] = None,
-        text_block_names: Optional[Union[str, List[str]]] = None,
+        floating_text_block_names: Optional[Union[str, Sequence[str]]] = None,
+        text_block_names: Optional[Union[str, Sequence[str]]] = None,
         text_containers_to_text_block: bool = False,
     ) -> None:
         """
@@ -322,7 +343,7 @@ class TextOrderService(PipelineComponent):
         for text_block in block_anns:
             text_container_ann_ids = text_block.get_relationship(names.C.CHILD)
             text_container_anns = dp.get_annotation(
-                annotation_ids=text_container_ann_ids if text_container_ann_ids is not None else [],
+                annotation_ids=text_container_ann_ids,
                 category_names=self._text_container,
             )
             raw_reading_order_list = _reading_lines(dp.image_id, text_container_anns)
