@@ -19,7 +19,10 @@
 Init module for train package
 """
 
-from ..utils.file_utils import tensorpack_available, tf_available
+from ..utils.file_utils import detectron2_available, pytorch_available, tensorpack_available, tf_available
 
 if tf_available() and tensorpack_available():
-    from .tp_frcnn_train import *
+    from .tp_frcnn_train import train_faster_rcnn
+
+if pytorch_available() and detectron2_available():
+    from .d2_frcnn_train import train_d2_faster_rcnn
