@@ -8,11 +8,11 @@
 Utilities for maintaining dependencies and dealing with external library packages. Parts of this file is adapted from
 https://github.com/huggingface/transformers/blob/master/src/transformers/file_utils.py
 """
-
 import importlib.util
 import multiprocessing as mp
 import string
 import subprocess
+import sys
 from os import environ
 from shutil import which
 from typing import Tuple, Union
@@ -21,6 +21,7 @@ import importlib_metadata
 from packaging import version
 
 from .detection_types import Requirement
+from .logger import logger
 from .metacfg import AttrDict
 
 # Tensorflow and Tensorpack dependencies
@@ -41,12 +42,11 @@ def tf_available() -> bool:
     return bool(_TF_AVAILABLE)
 
 
-def get_tensorflow_requirement() -> Requirement:
+def get_tf_version() -> str:
     """
-    Returns Tensorflow requirement
+    Determine the TF version which is installed
     """
-
-    tf_requirement_satisfied = False
+    tf_version = "0.0"
     if tf_available():
         candidates: Tuple[str, ...] = (
             "tensorflow",
@@ -60,19 +60,29 @@ def get_tensorflow_requirement() -> Requirement:
             "tensorflow-rocm",
             "tensorflow-macos",
         )
-        tf_version = "0.0"
+
         for pkg in candidates:
             try:
-                tf_version = importlib_metadata.version(pkg)  # type: ignore
+                tf_version = importlib_metadata.version(pkg)
                 break
             except importlib_metadata.PackageNotFoundError:
                 pass
-        _tf_version_available = tf_version != "0.0"
-        if _tf_version_available:
-            if version.parse(tf_version) < version.parse("2.4.1"):
-                pass
-            else:
-                tf_requirement_satisfied = True
+    return tf_version
+
+
+def get_tensorflow_requirement() -> Requirement:
+    """
+    Returns Tensorflow requirement
+    """
+
+    tf_requirement_satisfied = False
+    tf_version = get_tf_version()
+    _tf_version_available = tf_version != "0.0"
+    if _tf_version_available:
+        if version.parse(tf_version) < version.parse("2.4.1"):
+            pass
+        else:
+            tf_requirement_satisfied = True
 
     return "tensorflow", tf_requirement_satisfied, _TF_ERR_MSG
 
@@ -93,7 +103,7 @@ def tf_addons_available() -> bool:
 
 def get_tf_addons_requirements() -> Requirement:
     """
-    Returns Tesnroflow Addons requirement
+    Returns Tensorflow Addons requirement
     """
     return "tensorflow-addons", tf_addons_available(), _TF_ADDONS_ERR_MSG
 
@@ -138,6 +148,17 @@ def get_pytorch_requirement() -> Requirement:
     return "torch", pytorch_available(), _PYTORCH_ERR_MSG
 
 
+# lxml
+_LXML_AVAILABLE = importlib.util.find_spec("lxml") is not None
+
+
+def lxml_available() -> bool:
+    """
+    Returns True if lxml is installed
+    """
+    return bool(_LXML_AVAILABLE)
+
+
 # Transformers
 _TRANSFORMERS_AVAILABLE = importlib.util.find_spec("transformers") is not None
 _TRANSFORMERS_ERR_MSG = "Transformers must be installed: >>install-dd-pt"
@@ -159,7 +180,11 @@ def get_transformers_requirement() -> Requirement:
 
 # Detectron2 related requirements
 _DETECTRON2_AVAILABLE = importlib.util.find_spec("detectron2") is not None
-_DETECTRON2_ERR_MSG = "Detectron2 must be installed: >>install-dd-pt"
+_DETECTRON2_ERR_MSG = (
+    "Detectron2 must be installed: >>install-dd-pt if you installed deepdoctection from source or "
+    "follow the official installation instructions "
+    "https://detectron2.readthedocs.io/en/latest/tutorials/install.html"
+)
 
 
 def detectron2_available() -> bool:
@@ -313,6 +338,66 @@ def get_pdfplumber_requirement() -> Requirement:
     return "pdfplumber", pdfplumber_available(), _PDFPLUMBER_ERR_MSG
 
 
+# pycocotools dependencies
+_COCOTOOLS_AVAILABLE = importlib.util.find_spec("pycocotools") is not None
+_COCOTOOLS_ERR_MSG = "pycocotools must be installed. >> pip install pycocotools==2.0.4"
+
+
+def cocotools_available() -> bool:
+    """
+    Returns True if pycocotools is installed
+    """
+    return bool(_COCOTOOLS_AVAILABLE)
+
+
+def get_cocotools_requirement() -> Requirement:
+    """
+    Returns cocotools requirement.
+    """
+    return "pycocotools", cocotools_available(), _COCOTOOLS_ERR_MSG
+
+
+# scipy dependency
+_SCIPY_AVAILABLE = importlib.util.find_spec("scipy") is not None
+
+
+def scipy_available() -> bool:
+    """
+    Returns True if scipy is installed
+    """
+    return bool(_SCIPY_AVAILABLE)
+
+
+# scikit-learn dependencies
+_SKLEARN_AVAILABLE = importlib.util.find_spec("sklearn") is not None
+_SKLEARN_ERR_MSG = "scikit-learn must be installed. >> pip install scikit-learn==1.0.2"
+
+
+def sklearn_available() -> bool:
+    """
+    Returns True if sklearn is installed
+    """
+    return bool(_SKLEARN_AVAILABLE)
+
+
+def get_sklearn_requirement() -> Requirement:
+    """
+    Returns sklearn requirement.
+    """
+    return "sklearn", sklearn_available(), _SKLEARN_ERR_MSG
+
+
+# qpdf related dependencies
+_QPDF_AVAILABLE = which("qpdf") is not None
+
+
+def qpdf_available() -> bool:
+    """
+    Returns True if qpdf is installed
+    """
+    return bool(_QPDF_AVAILABLE)
+
+
 # Textract related dependencies
 _BOTO3_AVAILABLE = importlib.util.find_spec("boto3") is not None
 _BOTO3_ERR_MSG = "Boto3 must be installed: >> pip install boto3"
@@ -369,9 +454,33 @@ def get_doctr_requirement() -> Requirement:
     """
     Return Doctr requirement
     """
+    if sys.platform == "darwin":
+        if not get_poppler_version():
+            return get_doctr_requirement()
+        # don't know yet how to check whether pango gdk-pixbuf libffi are installed
+        logger.info("package requires weasyprint. Check that poppler pango gdk-pixbuf libffi are installed")
     return "doctr", doctr_available(), _DOCTR_ERR_MSG
 
 
+# Fasttext related dependencies
+_FASTTEXT_AVAILABLE = importlib.util.find_spec("fasttext") is not None
+_FASTTEXT_ERR_MSG = "Fasttext must be installed. >> pip install fasttext"
+
+
+def fasttext_available() -> bool:
+    """
+    Returns True if fasttext is installed
+    """
+    return bool(_FASTTEXT_AVAILABLE)
+
+
+def get_fasttext_requirement() -> Requirement:
+    """
+    Return Fasttext requirement
+    """
+    return "fasttext", fasttext_available(), _FASTTEXT_ERR_MSG
+
+
 _S = AttrDict()
 _S.mp_context_set = False
 _S.freeze()
