@@ -12,12 +12,14 @@ The logger module itself has the common logging functions of Python's
 
 **Example:**
 
-..code-block::python
-    from deepdoctection.utils.logger import logger
-    logger.set_logger_dir("path/to/dir")
-    logger.info("Something has happened")
-    logger.warning("Attention!")
-    logger.error("Error happened!")
+    ..code-block::python
+
+        from deepdoctection.utils.logger import logger
+
+        logger.set_logger_dir("path/to/dir")
+        logger.info("Something has happened")
+        logger.warning("Attention!")
+        logger.error("Error happened!")
 """
 
 import errno
@@ -27,10 +29,13 @@ import os
 import shutil
 import sys
 from datetime import datetime
+from pathlib import Path
 from typing import Optional
 
 from termcolor import colored
 
+from .detection_types import Pathlike
+
 __all__ = ["logger", "set_logger_dir", "auto_set_dir", "get_logger_dir"]
 
 
@@ -79,7 +84,9 @@ def _get_time_str() -> str:
     return datetime.now().strftime("%m%d-%H%M%S")
 
 
-def _set_file(path: str) -> None:
+def _set_file(path: Pathlike) -> None:
+    if isinstance(path, Path):
+        path = path.as_posix()
     global _FILE_HANDLER  # pylint: disable=W0603
     if os.path.isfile(path):
         backup_name = path + "." + _get_time_str()
@@ -93,7 +100,7 @@ def _set_file(path: str) -> None:
     logger.info("Argv: %s ", sys.argv)
 
 
-def set_logger_dir(dir_name: str, action: Optional[str] = None) -> None:
+def set_logger_dir(dir_name: Pathlike, action: Optional[str] = None) -> None:
     """
     Set the directory for global logging.
 
@@ -109,9 +116,10 @@ def set_logger_dir(dir_name: str, action: Optional[str] = None) -> None:
                    Note that this option does not load old models or any other
                    old states for you. It simply does nothing.
     """
-    assert dir_name is not None
+    if isinstance(dir_name, Path):
+        dir_name = dir_name.as_posix()
     dir_name = os.path.normpath(dir_name)
-    global LOG_DIR, _FILE_HANDLER  # pylint: disable=W0602, W0603
+    global LOG_DIR, _FILE_HANDLER  # pylint: disable=W0603
     if _FILE_HANDLER:
         logger.removeHandler(_FILE_HANDLER)
         del _FILE_HANDLER
