@@ -20,6 +20,7 @@ Module for globally accessible fixtures
 """
 
 from copy import deepcopy
+from pathlib import Path
 from typing import Dict, List, Tuple
 
 import numpy as np
@@ -59,11 +60,19 @@ def fixture_image_results() -> DatapointImage:
 
 
 @fixture(name="path_to_tp_frcnn_yaml")
-def fixture_path_to_tp_frcnn_yaml() -> str:
+def fixture_path_to_tp_frcnn_yaml() -> Path:
     """
     path to tp frcnn yaml file
     """
-    return get_package_path() + "/configs/tp/layout/conf_frcnn_layout.yaml"
+    return get_package_path() / "configs/tp/layout/conf_frcnn_layout.yaml"
+
+
+@fixture(name="path_to_d2_frcnn_yaml")
+def fixture_path_to_d2_frcnn_yaml() -> Path:
+    """
+    path to d2 frcnn yaml file
+    """
+    return get_package_path() / "configs/d2/layout/CASCADE_RCNN_R_50_FPN_GN.yaml"
 
 
 @fixture(name="categories")
@@ -97,11 +106,11 @@ def fixture_np_image() -> ImageType:
 
 
 @fixture(name="path_to_tesseract_yaml")
-def fixture_path_to_tesseract_yaml() -> str:
+def fixture_path_to_tesseract_yaml() -> Path:
     """
     path to tesseract yaml file
     """
-    return get_package_path() + "/deepdoctection/configs/conf_tesseract.yaml"
+    return get_package_path() / "deepdoctection/configs/conf_tesseract.yaml"
 
 
 @fixture(name="dp_image")
@@ -433,3 +442,9 @@ def fixture_text_lines() -> List[Tuple[str, ImageType]]:
         ("cf234ec9-52cf-4710-94ce-288f0e055091", np.zeros((3, 3, 3), dtype=np.float32)),
         ("cf234ec9-52cf-4710-94ce-288f0e055092", np.zeros((3, 3, 3), dtype=np.float32)),
     ]
+
+
+@fixture(name="language_detect_result")
+def fixture_language_detect_result() -> DetectionResult:
+    """fixture language_detect_result"""
+    return DetectionResult(text="eng", score=0.9876)
