@@ -29,7 +29,7 @@ from deepdoctection.datapoint import BoundingBox, CategoryAnnotation, Image, Ima
 from deepdoctection.utils import get_uuid
 
 from ..test_utils import anns_to_ids
-from .conftest import TestPdfPage, WhiteImage  # pylint: disable=W0611
+from .conftest import TestPdfPage, WhiteImage
 
 
 class TestImage:
@@ -94,7 +94,7 @@ class TestImage:
         test_image.image = image.get_image_as_np_array()
 
         # Assert
-        assert_array_equal(test_image.get_image(type_id="np"), image.get_image_as_np_array())  # type: ignore
+        assert_array_equal(test_image.get_image().to_np_array(), image.get_image_as_np_array())
         assert test_image.height == image.get_bounding_box().height
         assert test_image.width == image.get_bounding_box().width
 
@@ -142,8 +142,8 @@ class TestImage:
         test_image.image = image.get_image_as_b64_string()  # type: ignore
 
         # Assert
-        assert_array_equal(test_image.get_image(type_id="np"), image.get_image_as_np_array())  # type: ignore
-        assert test_image.get_image(type_id="b64") == image.get_image_as_b64_string()
+        assert_array_equal(test_image.get_image().to_np_array(), image.get_image_as_np_array())
+        assert test_image.get_image().to_b64() == image.get_image_as_b64_string()
         assert test_image.height == image.get_bounding_box().height
         assert test_image.width == image.get_bounding_box().width
 
@@ -248,6 +248,7 @@ class TestImage:
         """
         test meth: image_ann_to_image add attr: image to ImageAnnotation and generates Image instance correctly
         """
+
         # Arrange
         test_image = Image(location=image.loc, file_name=image.file_name)
         test_image.image = ones((24, 85, 3), dtype=float32)
@@ -262,13 +263,13 @@ class TestImage:
         test_image.image_ann_to_image(annotation_id=annotation_id, crop_image=True)
 
         # Assert
-        assert hasattr(cat_1, "image")
-        assert cat_1.image.height == 4  # type: ignore # pylint: disable=E1101
-        assert cat_1.image.width == 10  # type: ignore # pylint: disable=E1101
-        assert cat_1.image.get_embedding(test_image.image_id) == BoundingBox(  # type: ignore  # pylint: disable=E1101
+        assert cat_1.image
+        assert cat_1.image.height == 4
+        assert cat_1.image.width == 10
+        assert cat_1.image.get_embedding(test_image.image_id) == BoundingBox(
             ulx=15.0, uly=20.0, width=10.0, height=4.0, absolute_coords=True
-        )  # pylint: disable=E1101
-        assert cat_1.image.image.shape == (4, 10, 3)  # type: ignore # pylint: disable=E1101
+        )
+        assert cat_1.image.image.shape == (4, 10, 3)
 
     @staticmethod
     def test_image_with_anns_can_be_exported(image: WhiteImage) -> None:
@@ -289,21 +290,18 @@ class TestImage:
         output = test_image.get_export()
 
         # Assert
-        assert (
-            "location" in output
-            and "file_name" in output
-            and "annotations" in output
-            and "image" in output
-            and "image_id" in output
-            and "embeddings" in output
-        )
+        assert "location" in output
+        assert "file_name" in output
+        assert "annotations" in output
+        assert "image" in output
+        assert "_image_id" in output
+        assert "embeddings" in output
+
         assert len(output["annotations"]) == 1
 
         ann = output["annotations"][0]
-        assert (
-            "active" in ann
-            and "annotation_id" in ann
-            and "category_name" in ann
-            and "category_id" in ann
-            and "score" in ann
-        )
+        assert "active" in ann
+        assert "_annotation_id" in ann
+        assert "category_name" in ann
+        assert "category_id" in ann
+        assert "score" in ann
