@@ -21,9 +21,9 @@ Testing the module eval.eval
 from typing import List
 from unittest.mock import MagicMock
 
-from pytest import fixture
+from pytest import fixture, mark
 
-from deepdoctection.dataflow import DataFromList  # type: ignore
+from deepdoctection.dataflow import DataFromList
 from deepdoctection.datapoint import Image
 from deepdoctection.datasets import DatasetCategories
 from deepdoctection.eval import CocoMetric, Evaluator
@@ -62,6 +62,8 @@ class TestEvaluator:
 
         self.evaluator = Evaluator(self._dataset, self._pipe_component, self._metric)
 
+    @mark.requires_tf
+    @mark.full
     def test_evaluator_runs_and_returns_distance(self, setup_method) -> None:  #  type: ignore  # pylint: disable=W0613
         """
         Testing evaluator runs and returns metric distance
