@@ -20,6 +20,7 @@ Module for fixtures
 """
 
 from typing import Dict
+from pathlib import Path
 
 import numpy as np
 
@@ -31,11 +32,11 @@ from deepdoctection.utils.detection_types import ImageType
 
 
 @fixture(name="path_to_d2_frcnn_yaml")
-def fixture_path_to_d2_frcnn_yaml() -> str:
+def fixture_path_to_d2_frcnn_yaml() -> Path:
     """
     path to d2 frcnn yaml file
     """
-    return get_package_path() + "/configs/d2/layout/CASCADE_RCNN_R_50_FPN_GN.yaml"
+    return get_package_path() / "configs/d2/layout/CASCADE_RCNN_R_50_FPN_GN.yaml"
 
 
 @fixture(name="categories")
